@@ -50,6 +50,7 @@ function get_disk_list {
         local rd_size
         local modfile=/etc/modprobe.d/99-brd.conf
         rd_size=$(getarg ramdisk_size=)
+        mkdir -p /etc/modprobe.d
         if [ -n "${rd_size}" ];then
             echo "options brd rd_size=${rd_size}" > ${modfile}
         fi
@@ -315,11 +316,11 @@ function check_image_integrity {
     then
         # verify with dialog based progress information
         setup_progress_fifo ${progress}
-        run_progress_dialog "${verify_text}" "${title_text}" &
         (
             pv --size $((blocks * blocksize)) --stop-at-size \
             -n "${image_target}" | md5sum - > ${verify_result}
-        ) 2>${progress}
+        ) 2>${progress} &
+        run_progress_dialog "${verify_text}" "${title_text}"
     else
         # verify with silently blocked console
         head --bytes=$((blocks * blocksize)) "${image_target}" |\
@@ -387,25 +388,25 @@ function get_remote_image_source_files {
             echo "--- ip a ---"; ip a
             echo "--- ip r ---"; ip r
         } >> /tmp/fetch.info 2>&1
-        report_and_quit \
-            "Failed to fetch ${image_md5_uri}, see /tmp/fetch.info"
+        show_log_and_quit \
+            "Failed to fetch ${image_md5_uri}" /tmp/fetch.info
     fi
 
     if ! fetch_file "${image_kernel_uri}" > "${metadata_dir}/linux";then
-        report_and_quit \
-            "Failed to fetch ${image_kernel_uri}, see /tmp/fetch.info"
+        show_log_and_quit \
+            "Failed to fetch ${image_kernel_uri}" /tmp/fetch.info
     fi
 
     if ! fetch_file "${image_initrd_uri}" > "${install_dir}/initrd.system_image"
     then
-        report_and_quit \
-            "Failed to fetch ${image_initrd_uri}, see /tmp/fetch.info"
+        show_log_and_quit \
+            "Failed to fetch ${image_initrd_uri}" /tmp/fetch.info
     fi
 
     if ! fetch_file "${image_config_uri}" > "/config.bootoptions"
     then
-        report_and_quit \
-            "Failed to fetch ${image_config_uri}, see /tmp/fetch.info"
+        show_log_and_quit \
+            "Failed to fetch ${image_config_uri}" /tmp/fetch.info
     fi
 
     echo "${image_uri}|${image_md5}"
