@@ -108,6 +108,9 @@ function initGlobalOptions {
 
     cow_file_mbsize=$(getarg rd.live.cowfile.mbsize)
     [ -z "${cow_file_mbsize}" ] && cow_file_mbsize="500"
+
+    cow_file_path=$(getarg rd.live.cowfile.path)
+    [ -z "${cow_file_path}" ] && cow_file_path="live_system.cow"
 }
 
 function mountIso {
@@ -193,7 +196,7 @@ function preparePersistentOverlayLoopBoot {
     # or the default size of 500MB
     local overlay_mount_point=$1
     local isoscan_loop_mount=/run/initramfs/isoscan
-    local cow_file_name="${isoscan_loop_mount}/live_system.cow"
+    local cow_file_name="${isoscan_loop_mount}/${cow_file_path}"
     mkdir -m 0755 -p "${overlay_mount_point}"
     if ! mount -o "remount,rw" "${isoscan_loop_mount}"; then
         return 1
@@ -277,7 +280,8 @@ function runMediaCheck {
 # Methods considered private
 #-----------------------------------------
 function _setup_interactive_service {
-    local service=/usr/lib/systemd/system/dracut-run-interactive.service
+    local service=/run/systemd/system/dracut-run-interactive.service
+    mkdir -p /run/systemd/system
     [ -e ${service} ] && return
     {
         echo "[Unit]"
@@ -291,7 +295,7 @@ function _setup_interactive_service {
         echo "Environment=DRACUT_SYSTEMD=1"
         echo "Environment=NEWROOT=/sysroot"
         echo "WorkingDirectory=/"
-        echo "ExecStart=/bin/bash /bin/dracut-interactive"
+        echo "ExecStart=/bin/bash /run/dracut-interactive"
         echo "Type=oneshot"
         echo "StandardInput=tty-force"
         echo "StandardOutput=inherit"
@@ -309,7 +313,7 @@ function _run_interactive {
 }
 
 function _run_dialog {
-    echo "dialog $*" >/bin/dracut-interactive
+    echo "dialog $*" >/run/dracut-interactive
     _run_interactive
 }
 
