@@ -7,13 +7,13 @@ check() {
 
 # called by dracut
 depends() {
-    echo rootfs-block dm kiwi-lib
+    echo network rootfs-block dm kiwi-lib
     return 0
 }
 
 # called by dracut
 installkernel() {
-    instmods squashfs loop overlay
+    instmods squashfs loop overlay nbd aoe
 }
 
 # called by dracut
@@ -21,7 +21,7 @@ install() {
     declare moddir=${moddir}
     declare systemdutildir=${systemdutildir}
     inst_multiple \
-        lsblk losetup grep cut mount
+        lsblk losetup grep cut mount nbd-client
     inst_hook cmdline 30 "${moddir}/parse-kiwi-overlay.sh"
     # kiwi-repart priority pre-mount hook is 20
     # overlay pre-mount needs to happend after any repartition
