@@ -292,11 +292,22 @@ function get_free_disk_bytes {
 
 function get_partition_table_type {
     local disk_device="$1"
+    local table_type
 
     # blkid doesn't work for dasd partitions, so on s390 parted is used
     # to detect the partition type (bsc#1209247)
     if [[ "$(uname -m)" =~ s390 ]];then
-        parted --script --machine "${disk_device}" print | grep "^${disk_device}" | cut -d":" -f6
+        table_type=$(
+            parted --script --machine "${disk_device}" print |\
+                grep "^${disk_device}" | cut -d":" -f6
+        )
+        if [ "${table_type}" = "msdos" ];then
+            # make sure to set a consistent table name for the
+            # DOS table type. In the initrd code we use 'dos'
+            # as identifier but parted reports msdos
+            table_type="dos"
+        fi
+        echo "${table_type}"
     else
         blkid -s PTTYPE -o value "$disk_device"
     fi
@@ -404,6 +415,11 @@ function resize_wanted {
     local root_device=$1
     local disk_device=$2
     kiwi_oemresizeonce=$(bool "${kiwi_oemresizeonce}")
+    if getargbool 0 rd.kiwi.oem.force_resize; then
+        info "System resize forced via rd.kiwi.oem.force_resize"
+        info "Activating resize operation"
+        return 0
+    fi
     if [ "${kiwi_oemresizeonce}" = "true" ];then
         current_rootpart_uuid=$(get_partition_uuid "${root_device}")
         if [ "${current_rootpart_uuid}" == "${kiwi_rootpartuuid}" ];then
