@@ -15,21 +15,20 @@ for project in \
     Virtualization:Appliances:Images:Testing_arm:ubuntu \
     Virtualization:Appliances:Images:Testing_x86:debian \
     Virtualization:Appliances:Images:Testing_s390:tumbleweed \
-    Virtualization:Appliances:Images:Testing_s390:sle15 \
+    Virtualization:Appliances:Images:Testing_s390:rawhide \
     Virtualization:Appliances:Images:Testing_arm:tumbleweed \
     Virtualization:Appliances:Images:Testing_arm:fedora \
     Virtualization:Appliances:Images:Testing_ppc:tumbleweed \
-    Virtualization:Appliances:Images:Testing_ppc:sle15 \
     Virtualization:Appliances:Images:Testing_x86:archlinux
 do
     echo "${project}"
     if [ ! "$1" = "refresh" ];then
         while read -r line;do
             echo -e "$(echo "${line}" |\
-                sed -e s@^F\ @'\\033[31mF \\e[0m'@ |\
-                sed -e s@^U\ @'\\033[33mU \\e[0m'@ |\
-                sed -e s@^D\ @'\\033[36mD \\e[0m'@ |\
-                sed -e s@^\\.@'\\033[32m.\\e[0m'@ |\
+                sed -e s@F\ @'\\033[31mF \\e[0m'@g |\
+                sed -e s@U\ @'\\033[33mU \\e[0m'@g |\
+                sed -e s@D\ @'\\033[36mD \\e[0m'@g |\
+                sed -e s@\\.@'\\033[32m.\\e[0m'@g |\
                 sed -e 's@^x\sF@x \\033[31mF\\e[0m'@ |\
                 sed -e 's@^x\sU@x \\033[33mU\\e[0m'@ |\
                 sed -e 's@^x\sD@x \\033[36mD\\e[0m'@ |\
