@@ -16,6 +16,7 @@
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
 from string import Template
+from textwrap import dedent
 import re
 import os
 import logging
@@ -41,7 +42,8 @@ from kiwi.exceptions import (
     KiwiBootLoaderGrubModulesError,
     KiwiBootLoaderGrubSecureBootError,
     KiwiBootLoaderGrubFontError,
-    KiwiDiskGeometryError
+    KiwiDiskGeometryError,
+    KiwiCommandNotFound
 )
 
 import kiwi.defaults as defaults
@@ -64,6 +66,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
 
                 {'grub_directory_name': 'grub|grub2'}
         """
+        self.efi_csm = True if self.xml_state.build_type.get_eficsm() is None \
+            else self.xml_state.build_type.get_eficsm()
         self.custom_args = custom_args
         self.config_options = []
         arch = Defaults.get_platform_name()
@@ -322,6 +326,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             self._copy_grub_config_to_efi_path(
                 self.efi_mount.mountpoint, self.early_boot_script_efi
             )
+        self._umount_system()
 
     def setup_install_image_config(
         self, mbrid, hypervisor='xen.gz', kernel='linux', initrd='initrd'
@@ -477,7 +482,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         :param string lookup_path: custom module lookup path
         """
         log.info('Creating grub2 bootloader images')
-        self.efi_boot_path = self.create_efi_path(in_sub_dir='')
+        if self.firmware.efi_mode():
+            self.efi_boot_path = self.create_efi_path(in_sub_dir='')
 
         log.info('--> Creating identifier file %s', mbrid.get_id())
         grub_boot_path = self._get_grub2_boot_path()
@@ -571,12 +577,19 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             # from the signed grub binary
             grub_image = Defaults.get_signed_grub_loader(self.root_dir, target_type)
             if grub_image and grub_image.filename:
+                strings_abspath = Path.which(
+                    'strings', access_mode=os.X_OK
+                )
+                if not strings_abspath:
+                    raise KiwiCommandNotFound(
+                        'strings command not found on buildhost'
+                    )
                 bash_command = [
-                    'strings', grub_image.filename, '|', 'grep', r'EFI\/'
+                    strings_abspath, grub_image.filename, '|', 'grep', r'EFI\/'
                 ]
                 efi_boot_path = Command.run(
                     ['bash', '-c', ' '.join(bash_command)],
-                    raise_on_error=False
+                    raise_on_error=False, raise_on_command_not_found=True
                 ).output
                 if efi_boot_path:
                     efi_boot_path = os.path.normpath(
@@ -601,7 +614,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             )
 
     def _supports_bios_modules(self):
-        if self.arch == 'ix86' or self.arch == 'x86_64':
+        if self.efi_csm and (
+            self.arch == 'ix86' or self.arch == 'x86_64' or Defaults.is_ppc64_arch(self.arch)
+        ):
             return True
         return False
 
@@ -918,6 +933,30 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 uuid, mbrid, lookup_path
             )
 
+    def _setup_chrp_config(self, mbrid):
+        early_boot_script = os.path.normpath(
+            os.sep.join(
+                [self._get_grub2_boot_path(), 'powerpc-ieee1275', 'grub.cfg']
+            )
+        )
+        self._create_early_boot_script_for_mbrid_search(
+            early_boot_script, mbrid
+        )
+        chrp_dir = os.path.normpath(os.sep.join([self.boot_dir, 'ppc']))
+        Path.create(chrp_dir)
+        chrp_bootinfo_file = os.sep.join([chrp_dir, 'bootinfo.txt'])
+        chrp_config = dedent('''
+            <chrp-boot>
+            <description>{os_name}</description>
+            <os-name>{os_name}</os-name>
+            <boot-script>boot &device;:1,\\boot\\grub2\\powerpc-ieee1275\\grub.elf</boot-script>
+            </chrp-boot>
+        ''').strip() + os.linesep
+        with open(chrp_bootinfo_file, 'w') as chrp_bootinfo:
+            chrp_bootinfo.write(
+                chrp_config.format(os_name=self.get_menu_entry_install_title())
+            )
+
     def _setup_bios_image(self, mbrid, lookup_path=None):
         """
         Provide bios grub image
@@ -932,6 +971,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             self._create_bios_image(
                 mbrid, lookup_path
             )
+        if Defaults.is_ppc64_arch(Defaults.get_platform_name()):
+            self._setup_chrp_config(mbrid)
+            return
         bash_command = ' '.join(
             [
                 'cat',
@@ -1203,7 +1245,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         )
 
     def _get_bios_modules_path(self, lookup_path=None):
-        return self._get_module_path('i386-pc', lookup_path)
+        return self._get_module_path(Defaults.get_bios_module_directory_name(), lookup_path)
 
     def _get_xen_modules_path(self, lookup_path=None):
         return self._get_module_path(
