@@ -16,7 +16,9 @@
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
 import os
+import glob
 from string import Template
+from contextlib import ExitStack
 from typing import Dict
 
 # project
@@ -28,10 +30,12 @@ from kiwi.mount_manager import MountManager
 from kiwi.storage.loop_device import LoopDevice
 from kiwi.storage.disk import Disk
 from kiwi.command import Command
+from kiwi.utils.os_release import OsRelease
 
 from kiwi.exceptions import (
     KiwiTemplateError,
-    KiwiBootLoaderTargetError
+    KiwiBootLoaderTargetError,
+    KiwiKernelLookupError
 )
 
 import kiwi.defaults as defaults
@@ -83,10 +87,20 @@ class BootLoaderSystemdBoot(BootLoaderSpecBase):
         :param str target:
             target identifier, one of disk, live(iso) or install(iso)
         """
+        os_release = OsRelease(root_dir)
+        try:
+            kernel_name = os.path.basename(
+                list(glob.iglob(f'{root_dir}/lib/modules/*'))[0]
+            )
+        except Exception as issue:
+            raise KiwiKernelLookupError(
+                f'Kernel lookup in {root_dir}/lib/modules failed with {issue}'
+            )
+        default_entry = f'{os_release.get("ID")}-{kernel_name}.conf'
         BootLoaderSystemdBoot._write_config_file(
             BootLoaderTemplateSystemdBoot().get_entry_template(),
-            root_dir + '/boot/efi/loader/entries/main.conf',
-            self._get_template_parameters()
+            root_dir + f'/boot/efi/loader/entries/{default_entry}',
+            self._get_template_parameters(default_entry)
         )
 
     def _create_embedded_fat_efi_image(self, path: str):
@@ -104,49 +118,47 @@ class BootLoaderSystemdBoot(BootLoaderSpecBase):
         Command.run(
             ['sgdisk', '-n', ':1.0', '-t', '1:EF00', path]
         )
-        loop_provider = LoopDevice(path)
-        loop_provider.create(overwrite=False)
-        disk = Disk('gpt', loop_provider)
-        disk.map_partitions()
-        disk.partitioner.partition_id = 1
-        disk._add_to_map('efi')
-        Command.run(
-            ['mkdosfs', '-n', 'BOOT', disk.partition_map['efi']]
-        )
-        Path.create(f'{self.root_dir}/boot/efi')
-        efi_mount = MountManager(
-            device=disk.partition_map['efi'],
-            mountpoint=f'{self.root_dir}/boot/efi'
-        )
-        device_mount = MountManager(
-            device='/dev',
-            mountpoint=f'{self.root_dir}/dev'
-        )
-        proc_mount = MountManager(
-            device='/proc',
-            mountpoint=f'{self.root_dir}/proc'
-        )
-        sys_mount = MountManager(
-            device='/sys',
-            mountpoint=f'{self.root_dir}/sys'
-        )
-        efi_mount.mount()
-        device_mount.bind_mount()
-        proc_mount.bind_mount()
-        sys_mount.bind_mount()
-        try:
-            self._run_bootctl(self.root_dir)
-            self.set_loader_entry(self.root_dir, self.target.live)
-        finally:
-            efi_mount.umount()
-            device_mount.umount()
-            proc_mount.umount()
-            sys_mount.umount()
-        Command.run(
-            ['dd', f'if={disk.partition_map["efi"]}', f'of={path}.img']
-        )
-        del disk
-        del loop_provider
+        with LoopDevice(path) as loop_provider:
+            loop_provider.create(overwrite=False)
+            with Disk('gpt', loop_provider) as disk:
+                disk.map_partitions()
+                disk.partitioner.partition_id = 1
+                disk._add_to_map('efi')
+                Command.run(
+                    ['mkdosfs', '-n', 'BOOT', disk.partition_map['efi']]
+                )
+                Path.create(f'{self.root_dir}/boot/efi')
+                with ExitStack() as stack:
+                    efi_mount = MountManager(
+                        device=disk.partition_map['efi'],
+                        mountpoint=f'{self.root_dir}/boot/efi'
+                    )
+                    stack.push(efi_mount)
+                    device_mount = MountManager(
+                        device='/dev',
+                        mountpoint=f'{self.root_dir}/dev'
+                    )
+                    stack.push(device_mount)
+                    proc_mount = MountManager(
+                        device='/proc',
+                        mountpoint=f'{self.root_dir}/proc'
+                    )
+                    stack.push(proc_mount)
+                    sys_mount = MountManager(
+                        device='/sys',
+                        mountpoint=f'{self.root_dir}/sys'
+                    )
+                    stack.push(sys_mount)
+                    efi_mount.mount()
+                    device_mount.bind_mount()
+                    proc_mount.bind_mount()
+                    sys_mount.bind_mount()
+                    self._run_bootctl(self.root_dir)
+                    self.set_loader_entry(self.root_dir, self.target.live)
+                Command.run(
+                    ['dd', f'if={disk.partition_map["efi"]}', f'of={path}.img']
+                )
+
         Command.run(
             ['mv', f'{path}.img', path]
         )
@@ -192,14 +204,17 @@ class BootLoaderSystemdBoot(BootLoaderSpecBase):
             self._get_template_parameters()
         )
 
-    def _get_template_parameters(self) -> Dict[str, str]:
+    def _get_template_parameters(
+        self, default_entry: str = 'main.conf'
+    ) -> Dict[str, str]:
         return {
             'kernel_file': self.custom_args['kernel'] or 'vmlinuz',
             'initrd_file': self.custom_args['initrd'] or 'initrd',
             'boot_options': self.cmdline,
             'boot_timeout': self.timeout,
             'bootpath': self.get_boot_path(),
-            'title': self.get_menu_entry_title()
+            'title': self.get_menu_entry_title(),
+            'default_entry': default_entry
         }
 
     @staticmethod
