@@ -26,6 +26,7 @@ from kiwi.bootloader.install.base import BootLoaderInstallBase
 from kiwi.command import Command
 from kiwi.defaults import Defaults
 from kiwi.mount_manager import MountManager
+from kiwi.system.setup import SystemSetup
 from kiwi.path import Path
 
 from kiwi.exceptions import (
@@ -68,6 +69,7 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
         self.shim_install_arguments = []
         self.firmware = None
         self.root_mount = None
+        self.sysfs_mount = None
         self.volumes = None
         self.root_volume_name = None
         self.target_removable = None
@@ -130,6 +132,13 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
                 'No grub boot code installation on %s', self.arch
             )
             return False
+        elif self.firmware.efi_mode() and not self.firmware.legacy_bios_mode():
+            # In EFI mode without CSM, no install
+            # of grub2 boot code makes sense
+            log.info(
+                'No grub boot code installation in EFI only mode'
+            )
+            return False
         return True
 
     def install(self):
@@ -205,6 +214,7 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
                 # grub2-zipl-setup and has no other job to do we can
                 # circumvent this problem by directly calling grub2-zipl-setup
                 # instead.
+                self.sysfs_mount.umount()
                 Command.run(
                     [
                         'chroot', self.root_mount.mountpoint,
@@ -252,6 +262,10 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
                     ['mv', zipl_config_file, zipl_config_file + '.kiwi']
                 )
 
+            # Rebuild security context
+            setup = SystemSetup(self.xml_state, self.root_mount.mountpoint)
+            setup.setup_selinux_file_contexts()
+
     def secure_boot_install(self):
         if self.firmware and self.firmware.efi_mode() == 'uefi' and (
             Defaults.is_x86_arch(self.arch)
@@ -367,12 +381,12 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
         stack.push(proc_mount)
         proc_mount.bind_mount()
 
-        sysfs_mount = MountManager(
+        self.sysfs_mount = MountManager(
             device='/sys',
             mountpoint=self.root_mount.mountpoint + '/sys'
         )
-        stack.push(sysfs_mount)
-        sysfs_mount.bind_mount()
+        stack.push(self.sysfs_mount)
+        self.sysfs_mount.bind_mount()
 
     def _disable_grub2_install(self, root_path):
         if os.access(root_path, os.W_OK):
