@@ -852,7 +852,8 @@ class DiskBuilder:
             ):
                 with ImageSystem(
                     device_map, self.root_dir,
-                    system.get_volumes() if self.volume_manager_name else {}
+                    system.get_volumes() if self.volume_manager_name else {},
+                    self.custom_partitions if self.custom_partitions else {}
                 ) as image_system:
                     image_system.mount()
                     disk_system = SystemSetup(
@@ -1753,8 +1754,8 @@ class DiskBuilder:
                 custom_install_arguments
             )
             bootloader = BootLoaderInstall.new(
-                self.bootloader, self.root_dir, disk.storage_provider,
-                custom_install_arguments
+                self.bootloader, self.xml_state, self.root_dir,
+                disk.storage_provider, custom_install_arguments
             )
             if bootloader.install_required():
                 bootloader.install()
