@@ -74,6 +74,8 @@ class LiveImageBuilder:
             Defaults.get_volume_id()
         self.mbrid = SystemIdentifier()
         self.mbrid.calculate_id()
+        self.application_id = self.xml_state.build_type.get_application_id() or \
+            self.mbrid.get_id()
         self.publisher = xml_state.build_type.get_publisher() or \
             Defaults.get_publisher()
         self.custom_args = custom_args
@@ -131,7 +133,7 @@ class LiveImageBuilder:
 
         # custom iso metadata
         log.info('Using following live ISO metadata:')
-        log.info('--> Application id: {0}'.format(self.mbrid.get_id()))
+        log.info('--> Application id: {0}'.format(self.application_id))
         log.info('--> Publisher: {0}'.format(self.publisher))
         log.info('--> Volume id: {0}'.format(self.volume_id))
         custom_iso_args = {
@@ -140,7 +142,9 @@ class LiveImageBuilder:
                 'preparer': Defaults.get_preparer(),
                 'volume_id': self.volume_id,
                 'mbr_id': self.mbrid.get_id(),
-                'efi_mode': self.firmware.efi_mode()
+                'application_id': self.application_id,
+                'efi_mode': self.firmware.efi_mode(),
+                'legacy_bios_mode': self.firmware.legacy_bios_mode()
             }
         }
 
@@ -188,6 +192,8 @@ class LiveImageBuilder:
                 config_file=self.root_dir + '/etc/dracut.conf.d/02-livecd.conf'
             )
             self.boot_image.create_initrd(self.mbrid)
+            # Clean up leftover dracut config file (which can break installs)
+            os.unlink(self.root_dir + '/etc/dracut.conf.d/02-livecd.conf')
             if self.bootloader == 'systemd_boot':
                 # make sure the initrd name follows the dracut
                 # naming conventions
@@ -240,7 +246,7 @@ class LiveImageBuilder:
         filesystem_setup = FileSystemSetup(
             self.xml_state, self.root_dir
         )
-        if root_filesystem != 'squashfs':
+        if root_filesystem not in ['squashfs', 'erofs']:
             # Create a filesystem image of the specified type
             # and put it into a SquashFS container
             root_image = Temporary().new_file()
@@ -296,12 +302,15 @@ class LiveImageBuilder:
         else:
             # Put the root filesystem into SquashFS directly
             with FileSystem.new(
-                name='squashfs',
+                name=root_filesystem,
                 device_provider=DeviceProvider(),
                 root_dir=self.root_dir + os.sep,
                 custom_args={
                     'compression':
                         self.xml_state.build_type.get_squashfscompression()
+                } if root_filesystem == 'squashfs' else {
+                    'compression':
+                        self.xml_state.build_type.get_erofscompression()
                 }
             ) as live_container_image:
                 container_image = Temporary().new_file()
@@ -310,6 +319,12 @@ class LiveImageBuilder:
                 )
                 Path.create(self.media_dir.name + '/LiveOS')
                 os.chmod(container_image.name, 0o644)
+                # Note: we keep the filename of the read-only image as it is
+                # even if another read-only filesystem not matching this
+                # filename is used. This is because the following filename
+                # is also used in the initrd code for the kiwi-live and
+                # dmsquash dracut modules. The name can be overwritten
+                # with the rd.live.squashimg boot option though.
                 shutil.copy(
                     container_image.name,
                     self.media_dir.name + '/LiveOS/squashfs.img'
