@@ -91,6 +91,7 @@ RUNTIME_CHECKER_METADATA = '{}/runtime_checker_metadata.yml'.format(
 ) if MODULE_SPEC else 'unknown'
 
 TEMP_DIR = '/var/tmp'
+LOCAL_CONTAINERS = '/var/tmp/kiwi_containers'
 CUSTOM_RUNTIME_CONFIG_FILE = None
 PLATFORM_MACHINE = platform.machine()
 EFI_FAT_IMAGE_SIZE = 20
@@ -207,6 +208,24 @@ class Defaults:
             return True
         return False
 
+    @staticmethod
+    def is_ppc64_arch(arch):
+        """
+        Checks if machine architecture is ppc64 based
+
+        Any arch that matches little endian or big endian ppc64 architecture
+        causes the method to return True. Anything else will
+        cause the method to return False
+
+        :rtype: bool
+        """
+        ppc64_arch_names = [
+            'ppc64', 'ppc64le'
+        ]
+        if arch in ppc64_arch_names:
+            return True
+        return False
+
     @staticmethod
     def is_buildservice_worker():
         """
@@ -397,7 +416,7 @@ class Defaults:
         :rtype: list
         """
         exclude_list = [
-            'image', '.profile', '.kconfig'
+            'image', '.kconfig'
         ]
         if no_tmpdirs:
             exclude_list += ['run/*', 'tmp/*']
@@ -956,11 +975,11 @@ class Defaults:
         :rtype: str
         """
         bios_grub_core_patterns = [
-            '/usr/share/grub*/i386-pc/{0}'.format(
-                Defaults.get_bios_image_name()
+            '/usr/share/grub*/{0}/{1}'.format(
+                Defaults.get_bios_module_directory_name(), Defaults.get_bios_image_name()
             ),
-            '/usr/lib/grub*/i386-pc/{0}'.format(
-                Defaults.get_bios_image_name()
+            '/usr/lib/grub*/{0}/{1}'.format(
+                Defaults.get_bios_module_directory_name(), Defaults.get_bios_image_name()
             )
         ]
         for bios_grub_core_pattern in bios_grub_core_patterns:
@@ -1148,15 +1167,21 @@ class Defaults:
         return 10
 
     @staticmethod
-    def get_min_volume_mbytes():
+    def get_min_volume_mbytes(filesystem: str):
         """
         Provides default minimum LVM volume size in mbytes
+        per filesystem
 
         :return: mbsize value
 
         :rtype: int
         """
-        return 30
+        if filesystem == 'btrfs':
+            return 120
+        elif filesystem == 'xfs':
+            return 300
+        else:
+            return 30
 
     @staticmethod
     def get_lvm_overhead_mbytes():
@@ -1261,7 +1286,7 @@ class Defaults:
         :rtype: dict
         """
         return {
-            'x86_64': ['efi', 'uefi', 'bios', 'ec2hvm', 'ec2'],
+            'x86_64': ['efi', 'uefi', 'bios', 'ec2'],
             'i586': ['bios'],
             'i686': ['bios'],
             'ix86': ['bios'],
@@ -1376,13 +1401,13 @@ class Defaults:
     @staticmethod
     def get_bios_module_directory_name():
         """
-        Provides x86 BIOS directory name which stores the pc binaries
+        Provides BIOS directory name which stores the pc binaries
 
         :return: directory name
 
         :rtype: str
         """
-        return 'i386-pc'
+        return 'powerpc-ieee1275' if Defaults.is_ppc64_arch(Defaults.get_platform_name()) else 'i386-pc'
 
     @staticmethod
     def get_efi_image_name(arch):
@@ -1418,7 +1443,7 @@ class Defaults:
 
         :rtype: str
         """
-        return 'core.img'
+        return 'grub.elf' if Defaults.is_ppc64_arch(Defaults.get_platform_name()) else 'core.img'
 
     @staticmethod
     def get_default_boot_timeout_seconds():
@@ -1499,7 +1524,7 @@ class Defaults:
         """
         return [
             'ext2', 'ext3', 'ext4', 'btrfs', 'squashfs',
-            'xfs', 'fat16', 'fat32'
+            'xfs', 'fat16', 'fat32', 'erofs'
         ]
 
     @staticmethod
@@ -1622,6 +1647,17 @@ class Defaults:
         """
         return ['kis', 'pxe']
 
+    @staticmethod
+    def get_enclaves_image_types():
+        """
+        Provides supported enclave(initrd-only) image types
+
+        :return: enclave image type names
+
+        :rtype: list
+        """
+        return ['enclave']
+
     @staticmethod
     def get_boot_image_description_path():
         """
@@ -1752,6 +1788,17 @@ class Defaults:
         """
         return 'xorriso'
 
+    @staticmethod
+    def get_iso_media_tag_tool():
+        """
+        Provides default iso media tag tool
+
+        :return: name
+
+        :rtype: str
+        """
+        return 'checkmedia'
+
     @staticmethod
     def get_container_compression():
         """
