@@ -208,10 +208,10 @@ class KiwiDataStructureError(KiwiError):
     """
 
 
-class KiwiDebootstrapError(KiwiError):
+class KiwiDebianBootstrapError(KiwiError):
     """
-    Exception raised if not enough user data to call debootstrap
-    were provided or the debootstrap has failed.
+    Exception raised if the bootstrap installation for Debian
+    based systems has failed
     """
 
 
@@ -492,6 +492,13 @@ class KiwiKisBootImageError(KiwiError):
     """
 
 
+class KiwiEnclaveBootImageError(KiwiError):
+    """
+    Exception raised if no kernel image was found while
+    building an enclave image.
+    """
+
+
 class KiwiRaidSetupError(KiwiError):
     """
     Exception raised if invalid or not enough user data is provided
@@ -853,3 +860,10 @@ class KiwiBootLoaderDiskPasswordError(KiwiError):
     """
     Exception raised if the disk password could not be set
     """
+
+
+class KiwiEnclaveFormatError(KiwiError):
+    """
+    Exception raised if no enclave_format attribute specified
+    for the selected build type
+    """
