@@ -60,9 +60,7 @@ class FileSystemBase:
         # as a file there
         self.filesystem_mount: Optional[MountManager] = None
 
-        # bind the block device providing class instance to this object.
-        # This is done to guarantee the correct destructor order when
-        # the device should be released. This is only required if the
+        # the underlaying device provider. This is only required if the
         # filesystem required a block device to become created
         self.device_provider = device_provider
 
@@ -76,6 +74,9 @@ class FileSystemBase:
         self.post_init(custom_args)
         self.veritysetup: Optional[VeritySetup] = None
 
+    def __enter__(self):
+        return self
+
     def post_init(self, custom_args: Dict):
         """
         Post initialization method
@@ -172,11 +173,13 @@ class FileSystemBase:
             return self.filesystem_mount.mountpoint
         return None
 
-    def sync_data(self, exclude: List[str] = []):
+    def sync_data(self, exclude: List[str] = []) -> MountManager:
         """
-        Copy root data tree into filesystem
+        Copy data tree into filesystem
 
         :param list exclude: list of exclude dirs/files
+        :return: The mount created for syncing data. It should be used to
+            un-mount the filesystem again.
         """
         if not self.root_dir:
             raise KiwiFileSystemSyncError(
@@ -199,6 +202,7 @@ class FileSystemBase:
         data.sync_data(
             exclude=exclude, options=Defaults.get_sync_options()
         )
+        return self.filesystem_mount
 
     def create_verity_layer(
         self, blocks: Optional[int] = None, filename: str = None
@@ -262,6 +266,56 @@ class FileSystemBase:
             log.info('umount %s instance', type(self).__name__)
             self.filesystem_mount.umount()
 
+    def umount_volumes(self) -> None:
+        """
+        Consistency layer with regards to VolumeManager classes
+
+        Invokes umount
+        """
+        self.umount()
+
+    def mount_volumes(self) -> None:
+        """
+        Consistency layer with regards to VolumeManager classes
+
+        Invokes mount
+        """
+        self.mount()
+
+    def get_volumes(self) -> Dict:
+        """
+        Consistency layer with regards to VolumeManager classes
+
+        Raises
+        """
+        raise NotImplementedError
+
+    def get_root_volume_name(self) -> None:
+        """
+        Consistency layer with regards to VolumeManager classes
+
+        Raises
+        """
+        raise NotImplementedError
+
+    def get_fstab(
+        self, persistency_type: str = 'by-label', filesystem_name: str = ''
+    ) -> List[str]:
+        """
+        Consistency layer with regards to VolumeManager classes
+
+        Raises
+        """
+        raise NotImplementedError
+
+    def set_property_readonly_root(self) -> None:
+        """
+        Consistency layer with regards to VolumeManager classes
+
+        Raises
+        """
+        raise NotImplementedError
+
     def _map_size(self, size: float, from_unit: str, to_unit: str) -> float:
         """
         Return byte size value for given size and unit
@@ -345,6 +399,5 @@ class FileSystemBase:
                     ]
                 )
 
-    def __del__(self):
-        log.info('Cleaning up %s instance', type(self).__name__)
+    def __exit__(self, exc_type, exc_value, traceback):
         self.umount()
