@@ -18,7 +18,7 @@
 import os
 import logging
 from typing import (
-    Dict, List, Optional
+    Dict, List, Optional, Union
 )
 
 # project
@@ -66,36 +66,45 @@ class IsoToolsXorrIso(IsoToolsBase):
         raise KiwiIsoToolError('xorriso tool not found')
 
     def init_iso_creation_parameters(
-        self, custom_args: Optional[Dict[str, str]] = None
+        self, custom_args: Optional[Dict[str, Union[str, bool]]] = None
     ) -> None:
         """
         Create a set of standard parameters
 
         :param list custom_args: custom ISO meta data
         """
+        legacy_bios_mode = True
         if custom_args:
-            if 'mbr_id' in custom_args:
+            application_id = \
+                custom_args.get('application_id') or custom_args.get('mbr_id')
+            if application_id:
                 self.iso_parameters += [
-                    '-application_id', custom_args['mbr_id']
+                    '-application_id', format(application_id)
                 ]
             if 'publisher' in custom_args:
                 self.iso_parameters += [
-                    '-publisher', custom_args['publisher']
+                    '-publisher', format(custom_args['publisher'])
                 ]
             if 'preparer' in custom_args:
                 self.iso_parameters += [
-                    '-preparer_id', custom_args['preparer']
+                    '-preparer_id', format(custom_args['preparer'])
                 ]
             if 'volume_id' in custom_args:
                 self.iso_parameters += [
-                    '-volid', custom_args['volume_id']
+                    '-volid', format(custom_args['volume_id'])
                 ]
+            if 'legacy_bios_mode' in custom_args:
+                legacy_bios_mode = bool(custom_args['legacy_bios_mode'])
         catalog_file = self.boot_path + '/boot.catalog'
         self.iso_parameters += [
             '-joliet', 'on', '-padding', '0'
         ]
+        if Defaults.is_ppc64_arch(self.arch):
+            self.iso_parameters += [
+                '-compliance', 'untranslated_names'
+            ]
 
-        if Defaults.is_x86_arch(self.arch):
+        if Defaults.is_x86_arch(self.arch) and legacy_bios_mode:
             mbr_file = os.sep.join(
                 [
                     self.source_dir, self.boot_path, 'loader',
@@ -121,15 +130,20 @@ class IsoToolsXorrIso(IsoToolsBase):
                 '-boot_image', 'grub', 'grub2_boot_info=on'
             ]
 
-        self.iso_loaders += [
-            '-boot_image', 'any', 'partition_offset=16',
-            '-boot_image', 'any', 'cat_path={0}'.format(catalog_file),
-            '-boot_image', 'any', 'cat_hidden=on',
-            '-boot_image', 'any', 'boot_info_table=on',
-            '-boot_image', 'any', 'platform_id=0x00',
-            '-boot_image', 'any', 'emul_type=no_emulation',
-            '-boot_image', 'any', 'load_size=2048'
-        ]
+        if Defaults.is_ppc64_arch(self.arch):
+            self.iso_loaders += [
+                '-boot_image', 'any', 'chrp_boot_part=on'
+            ]
+        else:
+            self.iso_loaders += [
+                '-boot_image', 'any', 'partition_offset=16',
+                '-boot_image', 'any', 'cat_path={0}'.format(catalog_file),
+                '-boot_image', 'any', 'cat_hidden=on',
+                '-boot_image', 'any', 'boot_info_table=on',
+                '-boot_image', 'any', 'platform_id=0x00',
+                '-boot_image', 'any', 'emul_type=no_emulation',
+                '-boot_image', 'any', 'load_size=2048'
+            ]
 
     def add_efi_loader_parameters(self, loader_file: str) -> None:
         """
