@@ -19,6 +19,7 @@ import re
 import os
 import glob
 import logging
+import pathlib
 from typing import (
     List, Dict
 )
@@ -30,11 +31,12 @@ from kiwi.path import Path
 from kiwi.package_manager.base import PackageManagerBase
 from kiwi.system.root_bind import RootBind
 from kiwi.repository.apt import RepositoryApt
+from kiwi.utils.temporary import Temporary
 
 import kiwi.defaults as defaults
 
 from kiwi.exceptions import (
-    KiwiDebootstrapError,
+    KiwiDebianBootstrapError,
     KiwiRequestError,
     KiwiFileNotFound
 )
@@ -131,12 +133,11 @@ class PackageManagerApt(PackageManagerBase):
     ) -> CommandCallT:
         """
         Process package install requests for bootstrap phase (no chroot)
-        Either debootstrap or a prebuilt bootstrap package can be used
-        to bootstrap a new system.
+        Either a manual unpacking strategy or a prebuilt bootstrap
+        package can be used to bootstrap a new system.
 
         :param object root_bind:
-            instance of RootBind to manage kernel file systems before
-            debootstrap call
+            unused
         :param str bootstrap_package:
             package name of a bootstrap package
 
@@ -149,9 +150,7 @@ class PackageManagerApt(PackageManagerBase):
                 bootstrap_package
             )
         else:
-            return self._process_install_requests_bootstrap_debootstrap(
-                root_bind
-            )
+            return self._process_install_requests_bootstrap()
 
     def _process_install_requests_bootstrap_prebuild_root(
         self, bootstrap_package: str
@@ -205,117 +204,99 @@ class PackageManagerApt(PackageManagerBase):
         # Install eventual bootstrap packages as standard system install
         return self.process_install_requests()
 
-    def _process_install_requests_bootstrap_debootstrap(
-        self, root_bind: RootBind = None
-    ) -> CommandCallT:
+    def _process_install_requests_bootstrap(self) -> CommandCallT:
         """
-        Process package install requests for bootstrap phase (no chroot)
-        The debootstrap program is used to bootstrap a new system
+        Process package install requests for bootstrap phase (no chroot).
 
-        :param object root_bind: instance of RootBind to manage kernel
-            file systems before debootstrap call
-
-        :raises KiwiDebootstrapError: if no main distribution repository
-            is configured, if the debootstrap script is not found or if the
-            debootstrap script execution fails
+        :raises KiwiDebianBootstrapError
 
         :return: process results in command type
 
-        :rtype: namedtuple
+        :rtype: CommandCallT
         """
-        if not self.distribution:
-            raise KiwiDebootstrapError(
-                'No main distribution repository is configured'
-            )
-        bootstrap_script = '/usr/share/debootstrap/scripts/' + \
-            self.distribution
-        if not os.path.exists(bootstrap_script):
-            raise KiwiDebootstrapError(
-                'debootstrap script for %s distribution not found' %
-                self.distribution
-            )
-
-        # APT package manager does not support bootstrapping. To circumvent
-        # this limitation there is the debootstrap tool for APT based distros.
-        # Because of that there is a little overlap between KIWI and
-        # debootstrap. Debootstrap manages itself the kernel file systems for
-        # chroot environment, thus we need to umount the kernel file systems
-        # before calling debootstrap and remount them afterwards.
-        if root_bind:
-            root_bind.umount_kernel_file_systems()
-
-        # debootsrap will create its own dev/fd devices
-        debootstrap_device_node_conflicts = [
-            'dev/fd',
-            'dev/pts'
-        ]
-        for node in debootstrap_device_node_conflicts:
-            Path.wipe(os.path.normpath(os.sep.join([self.root_dir, node])))
-
-        if 'apt' in self.package_requests:
-            # debootstrap takes care to install apt
-            self.package_requests.remove('apt')
+        # we invoke apt-get install to download all the essential packages.
+        # With DPkg::Pre-Install-Pkgs, we specify a shell command that will
+        # receive the list of packages that will be installed on stdin.
+        # By configuring Debug::pkgDpkgPm=1, apt-get install will not
+        # actually execute any dpkg commands, so all it does is download
+        # the essential debs and tell us their full in the apt cache without
+        # actually installing them.
         try:
-            cmd = ['debootstrap']
-            if self.repository.unauthenticated == 'false' and \
-               os.path.exists(self.repository.keyring):
-                cmd.append('--keyring={}'.format(self.repository.keyring))
-            else:
-                cmd.append('--no-check-gpg')
-            if self.deboostrap_minbase:
-                cmd.append('--variant=minbase')
-            if self.package_requests:
-                cmd.append(
-                    '--include={}'.format(','.join(self.package_requests))
-                )
-            if self.repository.components:
-                cmd.append(
-                    '--components={0}'.format(
-                        ','.join(self.repository.components)
-                    )
-                )
-            self.cleanup_requests()
-            cmd.extend(
-                [self.distribution, self.root_dir, self.distribution_path]
+            # TODO: Drop once apt 2.5.4 is widely available.
+            pathlib.Path(f'{self.root_dir}/var/lib/dpkg').mkdir(
+                parents=True, exist_ok=True
             )
+            pathlib.Path(f'{self.root_dir}/var/lib/dpkg/status.kiwi').touch()
+            pathlib.Path(f'{self.root_dir}/var/lib/dpkg/available').touch()
 
-            return Command.call(cmd, self.command_env)
+            if 'apt' not in self.package_requests:
+                self.package_requests.append('apt')
+            update_cache = [
+                'apt-get'
+            ] + self.apt_get_args + self.custom_args + [
+                'update'
+            ]
+            result = Command.run(
+                update_cache, self.command_env
+            )
+            log.debug(
+                'Apt update: {0} {1}'.format(result.output, result.error)
+            )
+            package_names = Temporary(prefix='kiwi_debs_').new_file()
+            download_bootstrap = [
+                'apt-get'
+            ] + self.apt_get_args + self.custom_args + [
+                'install',
+                '-oDebug::pkgDPkgPm=1',
+                f'-oDPkg::Pre-Install-Pkgs::=cat >{package_names.name}',
+                '?essential'
+            ] + self.package_requests
+            # Download solved bootstrap packages
+            result = Command.run(
+                download_bootstrap, self.command_env
+            )
+            log.debug(
+                'Apt download: {0} {1}'.format(result.output, result.error)
+            )
+            # Extract bootstrap packages
+            with open(package_names.name) as packages:
+                solved_debootstrap_packages = [p.rstrip() for p in packages]
+            self.command_env['PATH'] = '$PATH:/usr/bin:/bin:/usr/sbin:/sbin'
+            for package in solved_debootstrap_packages:
+                Command.run(
+                    [
+                        'bash', '-c',
+                        'dpkg-deb --fsys-tarfile {0} | tar -C {1} -x'.format(
+                            package, self.root_dir
+                        )
+                    ], self.command_env
+                )
+            # Run package scripts. Unfortuantely Debian based systems
+            # requires special sauce for bootstrap. See the exceptions
+            # we have to apply below:
+            #
+            # * manual order is required to make sure users(root) exists
+            # * the usr-merge strategy only works after bootstrap
+            #
+            # 1. Pass: Run package scripts, manual order
+            self._run_bootstrap_scripts(
+                solved_debootstrap_packages,
+                only_for=['base-passwd'], skip=['usrmerge']
+            )
+            # 2. Pass: Run package scripts in apt order
+            self._run_bootstrap_scripts(
+                solved_debootstrap_packages,
+                skip=['usrmerge']
+            )
+            self.cleanup_requests()
+            return Command.call(
+                update_cache, self.command_env
+            )
         except Exception as e:
-            raise KiwiDebootstrapError(
+            raise KiwiDebianBootstrapError(
                 '%s: %s' % (type(e).__name__, format(e))
             )
 
-    def get_error_details(self) -> str:
-        """
-        Provide further error details
-
-        Read the debootstrap log if available
-
-        :rtype: str
-        """
-        debootstrap_log_file = os.path.join(
-            self.root_dir, 'debootstrap/debootstrap.log'
-        )
-        if os.path.exists(debootstrap_log_file):
-            with open(debootstrap_log_file) as log_fd:
-                return log_fd.read() or 'logfile is empty'
-        return f'logfile {debootstrap_log_file!r} does not exist'
-
-    def post_process_install_requests_bootstrap(
-        self, root_bind: RootBind = None, delta_root: bool = False
-    ) -> None:
-        """
-        Mounts the kernel file systems to the chroot environment is
-        ready after the bootstrap procedure
-
-        :param object root_bind:
-            instance of RootBind to manage kernel file systems
-        :param bool delta_root:
-            root is derived from a base system
-        """
-        if root_bind:
-            root_bind.mount_kernel_file_systems(delta_root)
-
     def process_install_requests(self) -> CommandCallT:
         """
         Process package install requests for image phase (chroot)
@@ -536,3 +517,59 @@ class PackageManagerApt(PackageManagerBase):
         items = self.package_requests[:]
         self.cleanup_requests()
         return items
+
+    def _run_bootstrap_scripts(
+        self, solved_debootstrap_packages: List[str],
+        only_for: List[str] = [], skip: List[str] = []
+    ):
+        # TODO: this should not be needed but without setting
+        # the following environment variables no package pre/post
+        # script completes its task. I leave it up to the Debian
+        # experts to provide a fix if needed.
+        self.command_env['DPKG_MAINTSCRIPT_NAME'] = 'true'
+        self.command_env['DPKG_MAINTSCRIPT_PACKAGE'] = 'libc6'
+
+        post_script_dir = Temporary(
+            prefix='kiwi_debpost.', path=self.root_dir
+        ).new_dir()
+        for package in solved_debootstrap_packages:
+            package_base_name = os.path.basename(package)
+            go_ahead = False if only_for else True
+            for name in only_for:
+                if name in package_base_name:
+                    go_ahead = True
+                    break
+            for name in skip:
+                if name in package_base_name:
+                    go_ahead = False
+                    break
+            if not go_ahead:
+                continue
+            log.debug(
+                f'Running pre/post scripts for: {package_base_name}'
+            )
+            package_metadata_dir = \
+                f'{post_script_dir.name}/{os.path.basename(package)}'
+            Command.run(
+                ['dpkg', '-e', package, package_metadata_dir]
+            )
+            script_pre = f'{package_metadata_dir}/preinst'
+            script_post = f'{package_metadata_dir}/postinst'
+            # 1. preinst
+            if os.path.exists(script_pre):
+                Command.run(['chmod', '755', script_pre])
+                Command.run(
+                    [
+                        'chroot', self.root_dir,
+                        f'{script_pre.replace(self.root_dir, "")}', 'install'
+                    ], self.command_env
+                )
+            # 2. postinst
+            if os.path.exists(script_post):
+                Command.run(['chmod', '755', script_post])
+                Command.run(
+                    [
+                        'chroot', self.root_dir,
+                        f'{script_post.replace(self.root_dir, "")}', 'configure'
+                    ], self.command_env
+                )
