@@ -192,8 +192,8 @@ class RepositoryDnf5(RepositoryBase):
         prio: int = None, dist: str = None, components: str = None,
         user: str = None, secret: str = None, credentials_file: str = None,
         repo_gpgcheck: bool = False, pkg_gpgcheck: bool = False,
-        sourcetype: str = None, use_for_bootstrap: bool = False,
-        customization_script: str = None
+        sourcetype: str = None, customization_script: str = None,
+        architectures: str = None
     ) -> None:
         """
         Add dnf repository
@@ -211,9 +211,9 @@ class RepositoryDnf5(RepositoryBase):
         :param bool pkg_gpgcheck: enable package signature validation
         :param str sourcetype:
             source type, one of 'baseurl', 'metalink' or 'mirrorlist'
-        :param bool use_for_bootstrap: unused
         :param str customization_script:
             custom script called after the repo file was created
+        :param str architectures: unused
         """
         repo_file = self.shared_dnf_dir['reposd-dir'] + '/' + name + '.repo'
         self.repo_names.append(name + '.repo')
@@ -246,6 +246,8 @@ class RepositoryDnf5(RepositoryBase):
             repo_config.set(
                 name, 'module_hotfixes', '1'
             )
+        if not os.path.isdir(self.shared_dnf_dir['reposd-dir']):
+            Path.create(self.shared_dnf_dir['reposd-dir'])
         with open(repo_file, 'w') as repo:
             repo_config.write(repo)
         if customization_script:
