@@ -23,13 +23,17 @@ from typing import (
 )
 
 # project
+from kiwi.defaults import Defaults
 from kiwi.utils.temporary import Temporary
 from kiwi.command import Command
 from kiwi.storage.device_provider import DeviceProvider
 from kiwi.storage.mapped_device import MappedDevice
 from kiwi.partitioner import Partitioner
 from kiwi.runtime_config import RuntimeConfig
-from kiwi.exceptions import KiwiCustomPartitionConflictError
+from kiwi.exceptions import (
+    KiwiCustomPartitionConflictError,
+    KiwiError
+)
 
 ptable_entry_type = NamedTuple(
     'ptable_entry_type', [
@@ -68,15 +72,13 @@ class Disk(DeviceProvider):
             of that extended partition
         """
         self.partition_mapper = RuntimeConfig().get_mapper_tool()
-        # bind the underlaying block device providing class instance
-        # to this object (e.g loop) if present. This is done to guarantee
-        # the correct destructor order when the device should be released.
+        #: the underlaying device provider
         self.storage_provider = storage_provider
 
-        # list of protected map ids. If used in a custom partitions
-        # setup this will lead to a raise conditition in order to
-        # avoid conflicts with the existing partition layout and its
-        # customizaton capabilities
+        #: list of protected map ids. If used in a custom partitions
+        #: setup this will lead to a raise conditition in order to
+        #: avoid conflicts with the existing partition layout and its
+        #: customizaton capabilities
         self.protected_map_ids = [
             'root',
             'readonly',
@@ -88,6 +90,9 @@ class Disk(DeviceProvider):
             'efi'
         ]
 
+        #: Unified partition UUIDs according to systemd
+        self.gUID = self.get_discoverable_partition_ids()
+
         self.partition_map: Dict[str, str] = {}
         self.public_partition_id_map: Dict[str, str] = {}
         self.partition_id_map: Dict[str, str] = {}
@@ -99,6 +104,9 @@ class Disk(DeviceProvider):
 
         self.table_type = table_type
 
+    def __enter__(self):
+        return self
+
     def get_device(self) -> Dict[str, MappedDevice]:
         """
         Names of partition devices
@@ -160,6 +168,11 @@ class Disk(DeviceProvider):
             )
             self._add_to_map(map_name)
             self._add_to_public_id_map(id_name)
+            part_uuid = self.gUID.get(entry.partition_name)
+            if part_uuid:
+                self.partitioner.set_uuid(
+                    self.partition_id_map[map_name], part_uuid
+                )
 
     def create_root_partition(self, mbsize: str, clone: int = 0):
         """
@@ -181,6 +194,11 @@ class Disk(DeviceProvider):
             self._add_to_public_id_map('kiwi_RWPart')
         if 'kiwi_BootPart' not in self.public_partition_id_map:
             self._add_to_public_id_map('kiwi_BootPart')
+        root_uuid = self.gUID.get('root')
+        if root_uuid:
+            self.partitioner.set_uuid(
+                self.partition_id_map['root'], root_uuid
+            )
 
     def create_root_lvm_partition(self, mbsize: str, clone: int = 0):
         """
@@ -197,6 +215,11 @@ class Disk(DeviceProvider):
         self.partitioner.create('p.lxlvm', mbsize, 't.lvm')
         self._add_to_map('root')
         self._add_to_public_id_map('kiwi_RootPart')
+        root_uuid = self.gUID.get('root')
+        if root_uuid:
+            self.partitioner.set_uuid(
+                self.partition_id_map['root'], root_uuid
+            )
 
     def create_root_raid_partition(self, mbsize: str, clone: int = 0):
         """
@@ -216,6 +239,11 @@ class Disk(DeviceProvider):
         self._add_to_map('root')
         self._add_to_public_id_map('kiwi_RootPart')
         self._add_to_public_id_map('kiwi_RaidPart')
+        root_uuid = self.gUID.get('root')
+        if root_uuid:
+            self.partitioner.set_uuid(
+                self.partition_id_map['root'], root_uuid
+            )
 
     def create_root_readonly_partition(self, mbsize: str, clone: int = 0):
         """
@@ -235,6 +263,11 @@ class Disk(DeviceProvider):
         self.partitioner.create('p.lxreadonly', mbsize, 't.linux')
         self._add_to_map('readonly')
         self._add_to_public_id_map('kiwi_ROPart')
+        root_uuid = self.gUID.get('root')
+        if root_uuid:
+            self.partitioner.set_uuid(
+                self.partition_id_map['readonly'], root_uuid
+            )
 
     def create_boot_partition(self, mbsize: str, clone: int = 0):
         """
@@ -251,6 +284,11 @@ class Disk(DeviceProvider):
         self.partitioner.create('p.lxboot', mbsize, 't.linux')
         self._add_to_map('boot')
         self._add_to_public_id_map('kiwi_BootPart')
+        boot_uuid = self.gUID.get('xbootldr')
+        if boot_uuid:
+            self.partitioner.set_uuid(
+                self.partition_id_map['boot'], boot_uuid
+            )
 
     def create_prep_partition(self, mbsize: str):
         """
@@ -290,6 +328,11 @@ class Disk(DeviceProvider):
         self.partitioner.create('p.swap', mbsize, 't.swap')
         self._add_to_map('swap')
         self._add_to_public_id_map('kiwi_SwapPart')
+        swap_uuid = self.gUID.get('swap')
+        if swap_uuid:
+            self.partitioner.set_uuid(
+                self.partition_id_map['swap'], swap_uuid
+            )
 
     def create_efi_csm_partition(self, mbsize: str):
         """
@@ -316,6 +359,11 @@ class Disk(DeviceProvider):
         self.partitioner.create('p.UEFI', mbsize, 't.efi')
         self._add_to_map('efi')
         self._add_to_public_id_map('kiwi_EfiPart')
+        esp_uuid = self.gUID.get('esp')
+        if esp_uuid:
+            self.partitioner.set_uuid(
+                self.partition_id_map['efi'], esp_uuid
+            )
 
     def activate_boot_partition(self):
         """
@@ -423,6 +471,37 @@ class Disk(DeviceProvider):
             sorted(self.public_partition_id_map.items())
         )
 
+    def get_discoverable_partition_ids(self) -> Dict[str, str]:
+        """
+        Ask systemd for a list of standardized GUIDs for the
+        current architecture and return them in a dictionary.
+        If there is no such information available an empty
+        dictionary is returned
+
+        :return: key:value dict from systemd-id128
+
+        :rtype: dict
+        """
+        discoverable_ids = {}
+        try:
+            raw_lines = Command.run(
+                ['systemd-id128', 'show']
+            ).output.split(os.linesep)[1:]
+            for line in raw_lines:
+                if line:
+                    line = ' '.join(line.split())
+                    partition_name, uuid = line.split(' ')
+                    discoverable_ids[partition_name] = uuid
+        except KiwiError as issue:
+            log.warning(
+                f'Failed to obtain discoverable partition IDs: {issue}'
+            )
+            log.warning(
+                'Using built-in table'
+            )
+            discoverable_ids = Defaults.get_discoverable_partition_ids()
+        return discoverable_ids
+
     def _create_clones(
         self, name: str, clone: int, type_flag: str, mbsize: str
     ) -> None:
@@ -510,7 +589,7 @@ class Disk(DeviceProvider):
             self.partition_map[name] = device_node
             self.partition_id_map[name] = partition_number
 
-    def __del__(self):
+    def __exit__(self, exc_type, exc_value, traceback):
         if self.storage_provider.is_loop() and self.is_mapped:
             log.info('Cleaning up %s instance', type(self).__name__)
             try:
@@ -524,8 +603,9 @@ class Disk(DeviceProvider):
                     Command.run(
                         ['partx', '--delete', self.storage_provider.get_device()]
                     )
-            except Exception:
-                log.warning(
-                    'cleanup of partition device maps failed, %s still busy',
-                    self.storage_provider.get_device()
+            except Exception as issue:
+                log.error(
+                    'cleanup of partition maps on {} failed with: {}'.format(
+                        self.storage_provider.get_device(), issue
+                    )
                 )
