@@ -158,6 +158,7 @@ class SystemPrepare:
             for xml_repo in repository_sections:
                 repo_type = xml_repo.get_type()
                 repo_source = xml_repo.get_source().get_path()
+                repo_architectures = xml_repo.get_architectures()
                 repo_user = xml_repo.get_username()
                 repo_secret = xml_repo.get_password()
                 repo_alias = xml_repo.get_alias()
@@ -170,8 +171,6 @@ class SystemPrepare:
                     xml_repo
                 )
                 repo_sourcetype = xml_repo.get_sourcetype()
-                repo_use_for_bootstrap = \
-                    True if xml_repo.get_use_for_bootstrap() else False
                 log.info(
                     'Setting up repository %s', Uri.print_sensitive(repo_source)
                 )
@@ -211,8 +210,8 @@ class SystemPrepare:
                     repo_type, repo_priority, repo_dist, repo_components,
                     repo_user, repo_secret, uri.credentials_file_name(),
                     repo_repository_gpgcheck, repo_package_gpgcheck,
-                    repo_sourcetype, repo_use_for_bootstrap,
-                    repo_customization_script
+                    repo_sourcetype, repo_customization_script,
+                    repo_architectures
                 )
                 if clear_cache:
                     repo.delete_repo_cache(repo_alias)
@@ -576,9 +575,10 @@ class SystemPrepare:
                 )
             target_dir = self.root_bind.root_dir
             if archive_target_dir_dict.get(archive):
-                target_dir = os.path.join(
-                    target_dir,
-                    archive_target_dir_dict.get(archive)
+                target_dir = os.path.normpath(
+                    os.sep.join(
+                        [target_dir, archive_target_dir_dict.get(archive)]
+                    )
                 )
             log.info('--> target dir: %s', target_dir)
             tar = ArchiveTar(archive_file)
