@@ -23,7 +23,7 @@ import pathlib
 from collections import OrderedDict
 from collections import namedtuple
 from typing import (
-    Any, List, Optional
+    Any, List, Optional, Dict
 )
 
 # project
@@ -31,7 +31,9 @@ import kiwi.defaults as defaults
 
 from kiwi.xml_parse import repository
 from kiwi.utils.fstab import Fstab
-from kiwi.xml_state import XMLState
+from kiwi.xml_state import (
+    XMLState, FileT
+)
 from kiwi.runtime_config import RuntimeConfig
 from kiwi.mount_manager import MountManager
 from kiwi.system.uri import Uri
@@ -49,6 +51,7 @@ from kiwi.archive.tar import ArchiveTar
 from kiwi.utils.compress import Compress
 from kiwi.utils.command_capabilities import CommandCapabilities
 from kiwi.utils.rpm_database import RpmDataBase
+from kiwi.builder.template.container_import import BuilderTemplateSystemdUnit
 from kiwi.system.profile import Profile
 
 from kiwi.exceptions import (
@@ -85,6 +88,48 @@ class SystemSetup:
         self._preferences_lookup()
         self._oemconfig_lookup()
 
+    def setup_registry_import(self) -> None:
+        """
+        Fetch container(s) and activate systemd unit to load
+        containers from local oci-archive file during boot
+        """
+        container_files_to_load = []
+        container_execs_to_load = []
+        after_services = set()
+        for container in self.xml_state.get_containers():
+            log.info(f'Fetching container: {container.name}')
+            pathlib.Path(f'{self.root_dir}/{defaults.LOCAL_CONTAINERS}').mkdir(
+                parents=True, exist_ok=True
+            )
+            Command.run(
+                ['chroot', self.root_dir] + container.fetch_command
+            )
+            if container.load_command:
+                container_files_to_load.append(container.container_file)
+                container_execs_to_load.append(container.load_command)
+                if container.backend == 'docker':
+                    after_services.add('docker.service')
+
+        if container_files_to_load:
+            log.info('--> Setup kiwi_containers.service import unit')
+            service = BuilderTemplateSystemdUnit()
+            unit_template = service.get_container_import_template(
+                container_files_to_load, container_execs_to_load,
+                list(after_services)
+            )
+            unit = unit_template.substitute()
+            unit_file = '{0}/etc/systemd/system/{1}.service'.format(
+                self.root_dir, 'kiwi_containers'
+            )
+            with open(unit_file, 'w') as systemd:
+                systemd.write(unit)
+            Command.run(
+                [
+                    'chroot', self.root_dir,
+                    'systemctl', 'enable', 'kiwi_containers'
+                ]
+            )
+
     def import_description(self) -> None:
         """
         Import XML descriptions, custom scripts, archives and
@@ -106,6 +151,7 @@ class SystemSetup:
 
         self._import_custom_scripts()
         self._import_custom_archives()
+        self._import_custom_files()
         self._import_cdroot_archive()
 
     def script_exists(self, name: str) -> bool:
@@ -146,6 +192,7 @@ class SystemSetup:
             for xml_repo in repository_sections:
                 repo_type = xml_repo.get_type()
                 repo_source = xml_repo.get_source().get_path()
+                repo_architectures = xml_repo.get_architectures()
                 repo_user = xml_repo.get_username()
                 repo_secret = xml_repo.get_password()
                 repo_alias = xml_repo.get_alias()
@@ -158,7 +205,6 @@ class SystemSetup:
                     xml_repo
                 )
                 repo_sourcetype = xml_repo.get_sourcetype()
-                repo_use_for_bootstrap = False
                 uri = Uri(repo_source, repo_type)
                 repo_source_translated = uri.translate(
                     check_build_environment=False
@@ -182,8 +228,8 @@ class SystemSetup:
                     repo_type, repo_priority, repo_dist, repo_components,
                     repo_user, repo_secret, uri.credentials_file_name(),
                     repo_repository_gpgcheck, repo_package_gpgcheck,
-                    repo_sourcetype, repo_use_for_bootstrap,
-                    repo_customization_script
+                    repo_sourcetype, repo_customization_script,
+                    repo_architectures
                 )
 
     def import_cdroot_files(self, target_dir: str) -> None:
@@ -205,6 +251,14 @@ class SystemSetup:
             archive.extract(target_dir)
             break
 
+    def import_files(self) -> None:
+        system_files = self.xml_state.get_system_files()
+        bootstrap_files = self.xml_state.get_bootstrap_files()
+        if system_files:
+            self._sync_files(system_files)
+        if bootstrap_files:
+            self._sync_files(bootstrap_files)
+
     def import_overlay_files(
         self, follow_links: bool = False, preserve_owner_group: bool = False
     ) -> None:
@@ -976,6 +1030,50 @@ class SystemSetup:
             )
             break
 
+    def _import_custom_files(self):
+        """
+        Import custom file files
+        """
+        file_list = []
+        system_files = self.xml_state.get_system_files()
+        bootstrap_files = self.xml_state.get_bootstrap_files()
+        if system_files:
+            file_list += system_files.keys()
+        if bootstrap_files:
+            file_list += bootstrap_files.keys()
+
+        file_target_dir = os.path.join(
+            self.root_dir, defaults.IMAGE_METADATA_DIR
+        ) + os.sep
+
+        for file in file_list:
+            file_is_absolute = file.startswith(os.sep)
+            if file_is_absolute:
+                file_file = file
+            else:
+                file_file = os.path.join(self.description_dir, file)
+
+            file_exists = os.path.exists(file_file)
+
+            if not file_exists:
+                if self.derived_description_dir and not file_is_absolute:
+                    file_file = self.derived_description_dir + '/' + file
+                    file_exists = os.path.exists(file_file)
+
+            if file_exists:
+                log.info(
+                    '--> Importing {0} file to {1}'.format(
+                        file_file, file_target_dir
+                    )
+                )
+                Command.run(
+                    ['cp', file_file, file_target_dir]
+                )
+            else:
+                raise KiwiImportDescriptionError(
+                    f'Specified file {file_file} does not exist'
+                )
+
     def _import_custom_archives(self):
         """
         Import custom tar archive files
@@ -1358,6 +1456,45 @@ class SystemSetup:
             shared_mount.umount_lazy()
         return dbpath
 
+    def _sync_files(self, file_list: Dict[str, FileT]) -> None:
+        log.info("Installing files")
+        ordered_files = OrderedDict(sorted(file_list.items()))
+        for filename, file_t in list(ordered_files.items()):
+            target = file_t.target
+            target_owner = file_t.owner
+            target_permissions = file_t.permissions
+            file_file = '/'.join(
+                [self.root_dir, 'image', filename]
+            )
+            target_name = self.root_dir
+            if target:
+                target_name = os.path.normpath(
+                    os.sep.join([target_name, target])
+                )
+            log.info(f'--> file: {file_file} -> {target_name}')
+            if target_owner:
+                Command.run(
+                    [
+                        'chroot', self.root_dir,
+                        'chown', target_owner,
+                        file_file.replace(self.root_dir, '')
+                    ]
+                )
+            if target_permissions:
+                Command.run(
+                    [
+                        'chroot', self.root_dir,
+                        'chmod', target_permissions,
+                        file_file.replace(self.root_dir, '')
+                    ]
+                )
+            if os.path.dirname(target_name):
+                Path.create(os.path.dirname(target_name))
+            data = DataSync(file_file, target_name)
+            data.sync_data(
+                options=Defaults.get_sync_options()
+            )
+
     def _sync_overlay_files(
         self, overlay_directory, follow_links=False,
         preserve_owner_group=False, profile=None
