@@ -57,7 +57,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
 
         Store custom btrfs initialization arguments
 
-        :param list custom_args: custom btrfs volume manager arguments
+        :param dict custom_args: custom btrfs volume manager arguments
         """
         if custom_args:
             self.custom_args = custom_args
@@ -109,16 +109,16 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         """
         self.setup_mountpoint()
 
-        filesystem = FileSystem.new(
+        with FileSystem.new(
             name='btrfs',
             device_provider=MappedDevice(
                 device=self.device, device_provider=self.device_provider_root
             ),
             custom_args=self.custom_filesystem_args
-        )
-        filesystem.create_on_device(
-            label=self.custom_args['root_label']
-        )
+        ) as filesystem:
+            filesystem.create_on_device(
+                label=self.custom_args['root_label']
+            )
         self.toplevel_mount = MountManager(
             device=self.device, mountpoint=self.mountpoint
         )
@@ -224,6 +224,10 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                         os.path.normpath(toplevel + os.sep + volume.realpath)
                     ]
                 )
+                self._apply_quota(
+                    os.path.normpath(toplevel + os.sep + volume.realpath),
+                    volume.attributes
+                )
                 self.apply_attributes_on_volume(
                     toplevel, volume
                 )
@@ -269,7 +273,9 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                     volume_mount
                 )
 
-    def get_fstab(self, persistency_type='by-label', filesystem_name=None):
+    def get_fstab(
+        self, persistency_type: str = 'by-label', filesystem_name: str = ''
+    ) -> List[str]:
         """
         Implements creation of the fstab entries. The method
         returns a list of fstab compatible entries
@@ -353,13 +359,6 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         )
 
         for volume_mount in self.subvol_mount_list:
-            if self.volumes_mounted_initially:
-                toplevel = self.root_volume_name
-                if self.custom_args['root_is_snapshot']:
-                    toplevel = f'{self.root_volume_name}/.snapshots/1/snapshot'
-                volume_mount.mountpoint = os.path.normpath(
-                    volume_mount.mountpoint.replace(toplevel, '', 1)
-                )
             if not os.path.exists(volume_mount.mountpoint):
                 Path.create(volume_mount.mountpoint)
             subvol_path = volume_mount.get_attributes().get('subvol_path')
@@ -372,28 +371,16 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 options=[subvol_options]
             )
 
-        self.volumes_mounted_initially = True
-
-    def umount_volumes(self):
+    def umount_volumes(self) -> None:
         """
         Umount btrfs subvolumes
-
-        :return: True if all subvolumes are successfully unmounted
-
-        :rtype: bool
         """
-        all_volumes_umounted = True
         for volume_mount in reversed(self.subvol_mount_list):
             if volume_mount.is_mounted():
-                if not volume_mount.umount():
-                    all_volumes_umounted = False
+                volume_mount.umount()
 
-        if all_volumes_umounted:
-            if self.toplevel_mount.is_mounted():
-                if not self.toplevel_mount.umount():
-                    all_volumes_umounted = False
-
-        return all_volumes_umounted
+        if self.toplevel_mount.is_mounted():
+            self.toplevel_mount.umount()
 
     def get_mountpoint(self) -> str:
         """
@@ -405,6 +392,8 @@ class VolumeManagerBtrfs(VolumeManagerBase):
 
         :rtype: string
         """
+        if not self.mountpoint:
+            raise KiwiVolumeManagerSetupError("No mountpoint exists")
         sync_target: List[str] = [self.mountpoint]
         if self.root_volume_name != '/':
             sync_target.append(self.root_volume_name)
@@ -449,11 +438,22 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         root_is_readonly_snapshot = \
             self.custom_args['root_is_readonly_snapshot']
         if root_is_snapshot and root_is_readonly_snapshot:
-            sync_target = self.mountpoint
+            sync_target = self.get_mountpoint()
             Command.run(
                 ['btrfs', 'property', 'set', sync_target, 'ro', 'true']
             )
 
+    def _apply_quota(self, volume_path: str, attributes: List[str]):
+        for attribute in attributes:
+            if attribute.startswith('quota='):
+                quota = attribute.split('=')[1]
+                Command.run(
+                    ['btrfs', 'quota', 'enable', '--simple', volume_path]
+                )
+                Command.run(
+                    ['btrfs', 'qgroup', 'limit', quota, volume_path]
+                )
+
     def _has_root_volume(self) -> bool:
         has_root_volume = bool(self.custom_args['root_is_subvolume'])
         if self.custom_args['root_is_subvolume'] is None:
@@ -572,8 +572,6 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         with open(filename, 'w') as snapshot_info_file:
             snapshot_info_file.write(self._xml_pretty(snapshot))
 
-    def __del__(self):
+    def __exit__(self, exc_type, exc_value, traceback):
         if self.toplevel_mount:
-            log.info('Cleaning up %s instance', type(self).__name__)
-            if not self.umount_volumes():
-                log.warning('Subvolumes still busy')
+            self.umount_volumes()
