@@ -1,6 +1,6 @@
 import io
 from collections import namedtuple
-from mock import (
+from unittest.mock import (
     patch, Mock, MagicMock
 )
 from pytest import raises
