@@ -1,18 +1,20 @@
 import io
 from pytest import raises
-from mock import (
+from unittest.mock import (
     Mock, patch, call, MagicMock
 )
 from kiwi.bootloader.config.systemd_boot import BootLoaderSystemdBoot
 
 from kiwi.exceptions import (
     KiwiTemplateError,
-    KiwiBootLoaderTargetError
+    KiwiBootLoaderTargetError,
+    KiwiKernelLookupError
 )
 
 
 class TestBootLoaderSystemdBoot:
-    def setup(self):
+    @patch('kiwi.bootloader.config.bootloader_spec_base.FirmWare')
+    def setup(self, mock_FirmWare):
         self.state = Mock()
         self.state.xml_data.get_name.return_value = 'image-name'
         self.state.get_image_version.return_value = 'image-version'
@@ -33,7 +35,8 @@ class TestBootLoaderSystemdBoot:
             return_value='title'
         )
 
-    def setup_method(self, cls):
+    @patch('kiwi.bootloader.config.bootloader_spec_base.FirmWare')
+    def setup_method(self, cls, mock_FirmWare):
         self.setup()
 
     def test_setup_loader_raises_invalid_target(self):
@@ -41,6 +44,8 @@ class TestBootLoaderSystemdBoot:
             self.bootloader.setup_loader('iso')
 
     @patch('os.path.exists')
+    @patch('kiwi.bootloader.config.systemd_boot.OsRelease')
+    @patch('kiwi.bootloader.config.systemd_boot.glob.iglob')
     @patch('kiwi.bootloader.config.systemd_boot.BootImageBase.get_boot_names')
     @patch('kiwi.bootloader.config.systemd_boot.Path.wipe')
     @patch('kiwi.bootloader.config.systemd_boot.Path.create')
@@ -54,8 +59,14 @@ class TestBootLoaderSystemdBoot:
         mock_get_template_parameters, mock_write_config_file,
         mock_BootLoaderTemplateSystemdBoot, mock_Command_run,
         mock_Path_create, mock_Path_wipe, mock_BootImageBase_get_boot_names,
+        mock_iglob,
+        mock_OsRelease,
         mock_os_path_exists
     ):
+        mock_iglob.return_value = ['/lib/modules/5.3.18-59.10-default']
+        os_release = Mock()
+        os_release.get.return_value = 'opensuse-leap'
+        mock_OsRelease.return_value = os_release
         kernel_info = Mock()
         kernel_info.kernel_version = 'kernel-version'
         kernel_info.kernel_filename = 'kernel-filename'
@@ -65,13 +76,16 @@ class TestBootLoaderSystemdBoot:
         self.bootloader.setup_loader('disk')
         assert mock_write_config_file.call_args_list == [
             call(
-                mock_BootLoaderTemplateSystemdBoot.return_value.get_loader_template.return_value,
+                mock_BootLoaderTemplateSystemdBoot.
+                return_value.get_loader_template.return_value,
                 'system_root_mount/boot/efi/loader/loader.conf',
                 mock_get_template_parameters.return_value
             ),
             call(
-                mock_BootLoaderTemplateSystemdBoot.return_value.get_entry_template.return_value,
-                'system_root_mount/boot/efi/loader/entries/main.conf',
+                mock_BootLoaderTemplateSystemdBoot.
+                return_value.get_entry_template.return_value,
+                'system_root_mount/boot/efi/loader/entries/'
+                'opensuse-leap-5.3.18-59.10-default.conf',
                 mock_get_template_parameters.return_value
             )
         ]
@@ -104,10 +118,27 @@ class TestBootLoaderSystemdBoot:
             )
         ]
 
+    @patch('kiwi.bootloader.config.systemd_boot.OsRelease')
+    @patch('kiwi.bootloader.config.systemd_boot.glob.iglob')
     @patch.object(BootLoaderSystemdBoot, '_write_config_file')
-    def test_set_loader_entry(self, mock_write_config_file):
+    def test_set_loader_entry(
+        self, mock_write_config_file, mock_iglob, mock_OsRelease
+    ):
+        mock_iglob.return_value = ['/lib/modules/5.3.18-59.10-default']
+        os_release = Mock()
+        os_release.get.return_value = 'opensuse-leap'
+        mock_OsRelease.return_value = os_release
         self.bootloader.set_loader_entry('root_dir', 'disk')
 
+    @patch('kiwi.bootloader.config.systemd_boot.OsRelease')
+    @patch('kiwi.bootloader.config.systemd_boot.glob.iglob')
+    def test_set_loader_entry_kernel_lookup_raises(
+        self, mock_iglob, mock_OsRelease
+    ):
+        mock_iglob.return_value = None
+        with raises(KiwiKernelLookupError):
+            self.bootloader.set_loader_entry('root_dir', 'disk')
+
     def test_create_loader_image(self):
         self.bootloader.create_loader_image('disk')
         self.bootloader.create_efi_path.assert_called_once_with()
@@ -120,7 +151,8 @@ class TestBootLoaderSystemdBoot:
             'boot_options': '',
             'boot_timeout': 0,
             'bootpath': 'bootpath',
-            'title': 'title'
+            'title': 'title',
+            'default_entry': 'main.conf'
         }
 
     @patch('kiwi.bootloader.config.systemd_boot.Path.create')
@@ -164,7 +196,7 @@ class TestBootLoaderSystemdBoot:
     ):
         target = Mock()
         self.bootloader.target = target
-        mock_Disk.return_value.partition_map = {
+        mock_Disk.return_value.__enter__.return_value.partition_map = {
             'efi': 'efi_device'
         }
         self.bootloader._create_embedded_fat_efi_image('ESP')
