@@ -1,6 +1,6 @@
 import logging
 from collections import namedtuple
-from mock import (
+from unittest.mock import (
     patch, Mock, MagicMock, mock_open
 )
 from pytest import (
