@@ -18,6 +18,9 @@ class TestLiveImageBuilder:
         Defaults.set_platform_name('x86_64')
 
         self.firmware = Mock()
+        self.firmware.legacy_bios_mode = Mock(
+            return_value=True
+        )
         self.firmware.efi_mode = Mock(
             return_value='uefi'
         )
@@ -77,6 +80,9 @@ class TestLiveImageBuilder:
         self.xml_state.get_fs_create_option_list = Mock(
             return_value=['-O', 'option']
         )
+        self.xml_state.build_type.get_application_id = Mock(
+            return_value='0xffffffff'
+        )
         self.xml_state.build_type.get_flags = Mock(
             return_value=None
         )
@@ -146,10 +152,11 @@ class TestLiveImageBuilder:
     @patch('kiwi.builder.live.FileSystem.new')
     @patch('kiwi.builder.live.SystemSize')
     @patch('kiwi.builder.live.Defaults.get_grub_boot_directory_name')
+    @patch('os.unlink')
     @patch('os.path.exists')
     @patch('os.chmod')
     def test_create_overlay_structure_boot_on_systemd_boot(
-        self, mock_chmod, mock_exists, mock_grub_dir, mock_size,
+        self, mock_chmod, mock_exists, mock_unlink, mock_grub_dir, mock_size,
         mock_filesystem, mock_isofs, mock_Iso, mock_tag, mock_shutil,
         mock_Temporary, mock_setup_media_loader_directory, mock_DeviceProvider,
         mock_Command_run, mock_LoopDevice, mock_create_boot_loader_config
@@ -184,10 +191,11 @@ class TestLiveImageBuilder:
     @patch('kiwi.builder.live.FileSystem.new')
     @patch('kiwi.builder.live.SystemSize')
     @patch('kiwi.builder.live.Defaults.get_grub_boot_directory_name')
+    @patch('os.unlink')
     @patch('os.path.exists')
     @patch('os.chmod')
     def test_create_overlay_structure_boot_on_grub(
-        self, mock_chmod, mock_exists, mock_grub_dir, mock_size,
+        self, mock_chmod, mock_exists, mock_unlink, mock_grub_dir, mock_size,
         mock_filesystem, mock_isofs, mock_Iso, mock_tag, mock_shutil,
         mock_Temporary, mock_setup_media_loader_directory, mock_DeviceProvider,
         mock_LoopDevice, mock_create_boot_loader_config, xml_filesystem
@@ -198,6 +206,7 @@ class TestLiveImageBuilder:
         loop_provider = Mock()
         mock_LoopDevice.return_value.__enter__.return_value = loop_provider
         mock_exists.return_value = True
+        mock_unlink.return_value = True
         mock_grub_dir.return_value = 'grub2'
 
         temp_squashfs = Mock()
@@ -277,7 +286,7 @@ class TestLiveImageBuilder:
 
             filesystem.create_on_device.assert_called_once_with()
             filesystem.sync_data.assert_called_once_with([
-                'image', '.profile', '.kconfig',
+                'image', '.kconfig',
                 'run/*', 'tmp/*', '.buildenv', 'var/cache/kiwi'
             ])
 
@@ -350,12 +359,14 @@ class TestLiveImageBuilder:
             custom_args={
                 'meta_data': {
                     'mbr_id': '0xffffffff',
+                    'application_id': '0xffffffff',
                     'preparer': 'KIWI - https://github.com/OSInside/kiwi',
                     'publisher': 'Custom publisher',
                     'volume_id': 'volid',
                     'efi_mode': 'uefi',
                     'efi_loader': 'kiwi-tmpfile',
-                    'udf': True
+                    'udf': True,
+                    'legacy_bios_mode': True
                 }
             },
             device_provider=mock_DeviceProvider.return_value,
@@ -405,9 +416,10 @@ class TestLiveImageBuilder:
     @patch('kiwi.builder.live.IsoToolsBase.setup_media_loader_directory')
     @patch('kiwi.builder.live.Temporary')
     @patch('kiwi.builder.live.shutil')
+    @patch('os.unlink')
     def test_create_no_kernel_found(
-        self, mock_shutil, mock_Temporary, mock_setup_media_loader_directory,
-        mock_create_boot_loader_config
+        self, mock_unlink, mock_shutil, mock_Temporary,
+        mock_setup_media_loader_directory, mock_create_boot_loader_config
     ):
         self.firmware.bios_mode.return_value = False
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
@@ -419,9 +431,10 @@ class TestLiveImageBuilder:
     @patch('kiwi.builder.live.IsoToolsBase.setup_media_loader_directory')
     @patch('kiwi.builder.live.Temporary')
     @patch('kiwi.builder.live.shutil')
+    @patch('os.unlink')
     def test_create_no_hypervisor_found(
-        self, mock_shutil, mock_Temporary, mock_setup_media_loader_directory,
-        mock_create_boot_loader_config
+        self, mock_unlink, mock_shutil, mock_Temporary,
+        mock_setup_media_loader_directory, mock_create_boot_loader_config
     ):
         self.firmware.bios_mode.return_value = False
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
@@ -433,14 +446,16 @@ class TestLiveImageBuilder:
     @patch('kiwi.builder.live.IsoToolsBase.setup_media_loader_directory')
     @patch('kiwi.builder.live.Temporary')
     @patch('kiwi.builder.live.shutil')
+    @patch('os.unlink')
     @patch('os.path.exists')
     def test_create_no_initrd_found(
-        self, mock_exists, mock_shutil, mock_Temporary,
+        self, mock_exists, mock_unlink, mock_shutil, mock_Temporary,
         mock_setup_media_loader_directory,
         mock_create_boot_loader_config
     ):
         self.firmware.bios_mode.return_value = False
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
         mock_exists.return_value = False
+        mock_unlink.return_value = True
         with raises(KiwiLiveBootImageError):
             self.live_image.create()
