@@ -1,6 +1,8 @@
-from mock import patch
+from unittest.mock import (
+    patch, call
+)
 
-import mock
+import unittest.mock as mock
 
 from kiwi.filesystem.ext4 import FileSystemExt4
 
@@ -28,3 +30,11 @@ class TestFileSystemExt4:
         call = mock_command.call_args_list[0]
         assert mock_command.call_args_list[0] == \
             call(['mkfs.ext4', '-L', 'label', '-U', 'uuid', '/dev/foo', '100'])
+
+    @patch('kiwi.filesystem.ext4.Command.run')
+    def test_set_uuid(self, mock_command):
+        self.ext4.set_uuid()
+        assert mock_command.call_args_list == [
+            call(['e2fsck', '-y', '-f', '/dev/foo'], raise_on_error=False),
+            call(['tune2fs', '-f', '-U', 'random', '/dev/foo'])
+        ]
