@@ -1,6 +1,8 @@
-from mock import patch
+from unittest.mock import (
+    patch, call
+)
 
-import mock
+import unittest.mock as mock
 
 from kiwi.filesystem.xfs import FileSystemXfs
 
@@ -32,3 +34,11 @@ class TestFileSystemXfs:
                 '-m', 'uuid=uuid', '-d', 'size=100k', '/dev/foo'
             ]
         )
+
+    @patch('kiwi.filesystem.xfs.Command.run')
+    def test_set_uuid(self, mock_command):
+        self.xfs.set_uuid()
+        assert mock_command.call_args_list == [
+            call(['xfs_repair', '-L', '/dev/foo']),
+            call(['xfs_admin', '-U', 'generate', '/dev/foo'])
+        ]
