@@ -45,11 +45,36 @@ class TestIsoToolsXorrIso:
                     'publisher': 'org',
                     'preparer': 'preparer',
                     'volume_id': 'vol_id',
-                    'efi_mode': 'uefi'
+                    'efi_mode': 'uefi',
+                    'legacy_bios_mode': True
                 }
             )
             assert 'No hybrid MBR file found' in self._caplog.text
 
+    @patch('os.path.exists')
+    def test_init_iso_creation_parameters_ppc(self, mock_os_path_exists):
+        mock_os_path_exists.return_value = True
+        self.iso_tool.arch = 'ppc64le'
+        self.iso_tool.init_iso_creation_parameters(
+            {
+                'mbr_id': 'app_id',
+                'publisher': 'org',
+                'preparer': 'preparer',
+                'volume_id': 'vol_id',
+                'efi_mode': 'ofw',
+                'legacy_bios_mode': False
+            }
+        )
+        assert self.iso_tool.iso_parameters == [
+            '-application_id', 'app_id',
+            '-publisher', 'org',
+            '-preparer_id', 'preparer',
+            '-volid', 'vol_id',
+            '-joliet', 'on',
+            '-padding', '0',
+            '-compliance', 'untranslated_names'
+        ]
+
     @patch('os.path.exists')
     def test_init_iso_creation_parameters_efi(self, mock_os_path_exists):
         mock_os_path_exists.return_value = True
@@ -59,7 +84,8 @@ class TestIsoToolsXorrIso:
                 'publisher': 'org',
                 'preparer': 'preparer',
                 'volume_id': 'vol_id',
-                'efi_mode': 'uefi'
+                'efi_mode': 'uefi',
+                'legacy_bios_mode': True
             }
         )
         assert self.iso_tool.iso_parameters == [
@@ -85,6 +111,31 @@ class TestIsoToolsXorrIso:
             '-boot_image', 'any', 'load_size=2048'
         ]
 
+    @patch('os.path.exists')
+    def test_init_iso_creation_parameters_efi_custom_app_id(
+        self, mock_os_path_exists
+    ):
+        mock_os_path_exists.return_value = True
+        self.iso_tool.init_iso_creation_parameters(
+            {
+                'mbr_id': 'app_id',
+                'application_id': 'some_other_app_id',
+                'publisher': 'org',
+                'preparer': 'preparer',
+                'volume_id': 'vol_id',
+                'efi_mode': 'uefi',
+                'legacy_bios_mode': True
+            }
+        )
+        assert self.iso_tool.iso_parameters == [
+            '-application_id', 'some_other_app_id',
+            '-publisher', 'org',
+            '-preparer_id', 'preparer',
+            '-volid', 'vol_id',
+            '-joliet', 'on',
+            '-padding', '0'
+        ]
+
     def test_add_efi_loader_parameters(self):
         self.iso_tool.add_efi_loader_parameters('target_dir/efi-loader')
         assert self.iso_tool.iso_loaders == [
