@@ -191,7 +191,9 @@ class TestSystemPrepare:
 
     @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
     @patch('kiwi.system.prepare.ArchiveTar')
-    def test_install_bootstrap_archives_raises(self, mock_tar, mock_poll):
+    def test_install_bootstrap_archives_raises(
+        self, mock_tar, mock_poll
+    ):
         mock_tar.side_effect = Exception
         with raises(KiwiBootStrapPhaseFailed):
             self.system.install_bootstrap(self.manager)
@@ -216,7 +218,9 @@ class TestSystemPrepare:
 
     @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
     @patch('kiwi.system.prepare.ArchiveTar')
-    def test_install_system_archives_raises(self, mock_tar, mock_poll):
+    def test_install_system_archives_raises(
+        self, mock_tar, mock_poll
+    ):
         mock_tar.side_effect = KiwiInstallPhaseFailed
         with raises(KiwiInstallPhaseFailed):
             self.system.install_system(self.manager)
@@ -283,12 +287,12 @@ class TestSystemPrepare:
             call(
                 'uri-alias', 'uri', None, 42,
                 None, None, None, None, 'credentials-file', None, None,
-                'baseurl', False, None
+                'baseurl', None, None
             ),
             call(
                 'uri-alias', 'uri', 'rpm-md', None,
                 None, None, None, None, 'credentials-file', None, None,
-                None, False, '../data/script'
+                None, '../data/script', None
             )
         ]
         assert repo.delete_repo_cache.call_args_list == [
@@ -409,7 +413,8 @@ class TestSystemPrepare:
     @patch('kiwi.system.prepare.ArchiveTar')
     @patch('os.path.exists')
     def test_install_bootstrap_archive_from_derived_description(
-        self, mock_exists, mock_tar, mock_poll, mock_collection_type
+        self, mock_exists, mock_tar, mock_poll,
+        mock_collection_type
     ):
         mock_exists.return_value = False
         self.system.install_bootstrap(self.manager)
