@@ -1,6 +1,6 @@
 import sys
 import logging
-from mock import (
+from unittest.mock import (
     patch, call, Mock
 )
 from pytest import (
