@@ -61,13 +61,31 @@ class TestCliTask:
         mock_command_args.assert_called_once_with()
         mock_global_args.assert_called_once_with()
         assert mock_setLogLevel.call_args_list == [
-            call(logging.DEBUG), call(logging.CRITICAL, except_for=['file', 'socket'])
+            call(logging.DEBUG),
+            call(logging.CRITICAL, except_for=['file', 'socket'])
         ]
         mock_setLogFlag.assert_called_once_with('run-scripts-in-screen')
         mock_setlog.assert_called_once_with('stdout')
         mock_color.assert_called_once_with()
         mock_runtime_config.assert_called_once_with()
 
+        mock_setLogLevel.reset_mock()
+        mock_global_args.return_value = {
+            '--debug': True,
+            '--debug-run-scripts-in-screen': True,
+            '--logfile': 'some',
+            '--logsocket': 'log_socket',
+            '--loglevel': None,
+            '--color-output': True,
+            '--profile': ['vmxFlavour'],
+            '--type': None
+        }
+        self.task = CliTask()
+        assert mock_setLogLevel.call_args_list == [
+            call(logging.DEBUG),
+            call(logging.DEBUG, only_for=['file', 'socket'])
+        ]
+
     @patch('kiwi.logger.Logger.setLogLevel')
     @patch('kiwi.logger.Logger.setLogFlag')
     @patch('kiwi.logger.Logger.set_logfile')
@@ -142,6 +160,9 @@ class TestCliTask:
             None, None, None
         ]
 
+    def test_attr_token(self):
+        assert self.task.attr_token('a=b') == ['a', 'b']
+
     @patch('kiwi.tasks.base.RuntimeChecker')
     def test_load_xml_description(self, mock_runtime_checker):
         self.task.load_xml_description('../data/description')
