@@ -191,14 +191,25 @@ class TestResultBundleTask:
     @patch('os.path.islink')
     @patch('os.symlink')
     @patch('os.readlink')
+    @patch('os.path.realpath')
+    @patch('os.path.abspath')
     def test_process_result_bundle_as_rpm(
-        self, mock_os_readlink, mock_os_symlink, mock_os_path_islink,
-        mock_iglob, mock_unlink, mock_chdir, mock_exists, mock_checksum,
-        mock_compress, mock_path_wipe, mock_path_which, mock_path_create,
-        mock_command, mock_load, mock_Privileges_check_for_root_permissions
+        self, mock_os_path_abspath, mock_os_path_realpath, mock_os_readlink,
+        mock_os_symlink, mock_os_path_islink, mock_iglob, mock_unlink,
+        mock_chdir, mock_exists, mock_checksum, mock_compress,
+        mock_path_wipe, mock_path_which, mock_path_create, mock_command,
+        mock_load, mock_Privileges_check_for_root_permissions
     ):
+        def abspath(path):
+            if path == 'target_dir':
+                return 'target-dir'
+            else:
+                return 'bundle-dir'
+
         checksum = Mock()
         compress = Mock()
+        mock_os_readlink.return_value = 'readlink'
+        mock_os_path_abspath.side_effect = abspath
         mock_path_which.return_value = 'zsyncmake'
         compress.xz.return_value = 'compressed_filename'
         mock_compress.return_value = compress
@@ -216,14 +227,14 @@ class TestResultBundleTask:
         with patch('builtins.open', m_open, create=True):
             self.task.process()
 
-        mock_path_wipe.assert_called_once_with(self.abs_bundle_dir)
+        mock_path_wipe.assert_called_once_with('bundle-dir')
         mock_Privileges_check_for_root_permissions.assert_called_once_with()
         assert mock_command.call_args_list == [
             call(
                 [
                     'cp', 'test-image-1.2.3',
                     os.sep.join(
-                        [self.abs_bundle_dir, 'test-image-1.2.3-Build_42']
+                        ['bundle-dir', 'test-image-1.2.3-Build_42']
                     )
                 ]
             ),
@@ -231,23 +242,21 @@ class TestResultBundleTask:
                 [
                     'file',
                     os.sep.join(
-                        [self.abs_bundle_dir, 'test-image-1.2.3-Build_42']
+                        ['bundle-dir', 'test-image-1.2.3-Build_42']
                     )
                 ]
             ),
             call(
                 [
                     'rpmbuild', '--nodeps', '--nocheck', '--rmspec', '-bb',
-                    os.sep.join([self.abs_bundle_dir, 'test-image.spec'])
+                    os.sep.join(['bundle-dir', 'test-image.spec'])
                 ]
             ),
             call(
                 ['bash', '-c', 'mv noarch/*.rpm . && rmdir noarch']
             )
         ]
-        mock_chdir.assert_called_once_with(
-            self.abs_bundle_dir
-        )
+        mock_chdir.assert_called_once_with('bundle-dir')
         assert mock_unlink.called
 
     @patch('kiwi.tasks.result_bundle.Result.load')
@@ -306,6 +315,118 @@ class TestResultBundleTask:
             )
         ]
 
+    @patch('kiwi.tasks.result_bundle.Result.load')
+    @patch('kiwi.tasks.result_bundle.Command.run')
+    @patch('kiwi.tasks.result_bundle.Path.create')
+    @patch('os.path.exists')
+    @patch('os.path.islink')
+    @patch('os.unlink')
+    @patch('os.symlink')
+    @patch('os.readlink')
+    def test_process_result_bundle_with_bundle_format_for_vagrant_types(
+        self, mock_os_readlink, mock_os_symlink, mock_os_unlink,
+        mock_os_path_islink, mock_exists, mock_path_create, mock_command,
+        mock_load
+    ):
+        self.xml_state.profiles = None
+        self.xml_state.host_architecture = 'x86_64'
+        self.xml_state.get_build_type_name = Mock(
+            return_value='oem'
+        )
+        self.xml_state.xml_data.get_name = Mock(
+            return_value='Leap-15.2'
+        )
+
+        result = Result(self.xml_state)
+        result.add_bundle_format('%N-%T:%M')
+        result.add(
+            key='disk_image',
+            filename='/tmp/mytest/Leap-15.2.x86_64-1.15.2.vagrant.virtualbox.box',
+            use_for_bundle=True, compress=False, shasum=False
+        )
+
+        mock_exists.return_value = False
+        mock_load.return_value = result
+        self._init_command_args()
+
+        self.task.process()
+
+        assert mock_command.call_args_list == [
+            call(
+                [
+                    'cp',
+                    '/tmp/mytest/Leap-15.2.x86_64-1.15.2.vagrant.virtualbox.box',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.vagrant.virtualbox.box']
+                    )
+                ]
+            ),
+            call(
+                [
+                    'file',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.vagrant.virtualbox.box']
+                    )
+                ]
+            )
+        ]
+
+    @patch('kiwi.tasks.result_bundle.Result.load')
+    @patch('kiwi.tasks.result_bundle.Command.run')
+    @patch('kiwi.tasks.result_bundle.Path.create')
+    @patch('os.path.exists')
+    @patch('os.path.islink')
+    @patch('os.unlink')
+    @patch('os.symlink')
+    @patch('os.readlink')
+    def test_process_result_bundle_with_bundle_format_for_archive_types(
+        self, mock_os_readlink, mock_os_symlink, mock_os_unlink,
+        mock_os_path_islink, mock_exists, mock_path_create, mock_command,
+        mock_load
+    ):
+        self.xml_state.profiles = None
+        self.xml_state.host_architecture = 'x86_64'
+        self.xml_state.get_build_type_name = Mock(
+            return_value='oem'
+        )
+        self.xml_state.xml_data.get_name = Mock(
+            return_value='Leap-15.2'
+        )
+
+        result = Result(self.xml_state)
+        result.add_bundle_format('%N-%T:%M')
+        result.add(
+            key='disk_image',
+            filename='/tmp/mytest/Leap-15.2.x86_64-1.15.2.tar.xz',
+            use_for_bundle=True, compress=False, shasum=False
+        )
+
+        mock_exists.return_value = False
+        mock_load.return_value = result
+        self._init_command_args()
+
+        self.task.process()
+
+        assert mock_command.call_args_list == [
+            call(
+                [
+                    'cp',
+                    '/tmp/mytest/Leap-15.2.x86_64-1.15.2.tar.xz',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.tar.xz']
+                    )
+                ]
+            ),
+            call(
+                [
+                    'file',
+                    os.sep.join(
+                        [self.abs_bundle_dir, 'Leap-15.2-oem:1.tar.xz']
+                    )
+                ]
+            )
+        ]
+
     @patch('kiwi.tasks.result_bundle.Result.load')
     @patch('kiwi.tasks.result_bundle.Command.run')
     @patch('kiwi.tasks.result_bundle.Path.create')
