@@ -10,8 +10,6 @@ import kiwi
 
 from ..test_helper import argv_kiwi_tests
 
-from kiwi.exceptions import KiwiCommandError
-
 from kiwi.tasks.system_prepare import SystemPrepareTask
 
 
@@ -71,6 +69,8 @@ class TestSystemPrepareTask:
         self.task.command_args['prepare'] = False
         self.task.command_args['--description'] = '../data/description'
         self.task.command_args['--root'] = '../data/root-dir'
+        self.task.command_args['--set-type-attr'] = ['volid=some']
+        self.task.command_args['--set-release-version'] = '99'
         self.task.command_args['--allow-existing-root'] = False
         self.task.command_args['--set-repo'] = None
         self.task.command_args['--set-repo-credentials'] = None
@@ -171,6 +171,8 @@ class TestSystemPrepareTask:
         self.setup.setup_plymouth_splash.assert_called_once_with()
         self.setup.setup_timezone.assert_called_once_with()
         self.setup.setup_permissions.assert_called_once_with()
+        self.setup.import_files.assert_called_once_with()
+        self.setup.setup_registry_import.assert_called_once_with()
         self.setup.setup_selinux_file_contexts.assert_called_once_with()
 
         system_prepare.pinch_system.assert_has_calls(
@@ -178,33 +180,6 @@ class TestSystemPrepareTask:
         )
         assert system_prepare.clean_package_manager_leftovers.called
 
-    @patch('kiwi.xml_state.XMLState.get_package_manager')
-    @patch('kiwi.tasks.system_prepare.SystemPrepare')
-    def test_process_system_prepare_run_debootstrap_only_once(
-        self, mock_SystemPrepare, mock_get_package_manager
-    ):
-        manager = MagicMock()
-        system_prepare = Mock()
-        system_prepare.setup_repositories = Mock(
-            return_value=manager
-        )
-        mock_SystemPrepare.return_value.__enter__.return_value = system_prepare
-        self._init_command_args()
-        mock_get_package_manager.return_value = 'apt'
-        self.task.command_args['--allow-existing-root'] = True
-
-        # debootstrap must be called if chroot with apt-get failed
-        self.command.run.side_effect = KiwiCommandError('error')
-        self.task.process()
-        assert system_prepare.install_bootstrap.called
-
-        # debootstrap must not be called if chroot looks good
-        self.command.run.side_effect = None
-        system_prepare.install_bootstrap.reset_mock()
-        with self._caplog.at_level(logging.WARNING):
-            self.task.process()
-        assert not system_prepare.install_bootstrap.called
-
     @patch('kiwi.xml_state.XMLState.get_repositories_signing_keys')
     @patch('kiwi.tasks.system_prepare.SystemPrepare')
     def test_process_system_prepare_add_package(
@@ -249,6 +224,35 @@ class TestSystemPrepareTask:
             manager.__enter__.return_value, ['vim']
         )
 
+    @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_prepare.SystemPrepare')
+    def test_process_system_build_invalid_type_attribute(
+        self, mock_SystemPrepare, mock_log
+    ):
+        self._init_command_args()
+        self.task.command_args['--set-type-attr'] = [
+            'bogus=value'
+        ]
+        with self._caplog.at_level(logging.ERROR):
+            self.task.process()
+        assert 'Failed to set type attribute' in self._caplog.text
+
+    @patch('kiwi.xml_state.XMLState.get_repositories_signing_keys')
+    @patch('kiwi.xml_state.XMLState.get_preferences_sections')
+    @patch('kiwi.logger.Logger.set_logfile')
+    @patch('kiwi.tasks.system_prepare.SystemPrepare')
+    def test_process_system_build_release_version_no_overwrite(
+        self, mock_SystemPrepare, mock_logger,
+        mock_get_preferences_sections, mock_get_repositories_signing_keys
+    ):
+        preferences = MagicMock()
+        preferences.get_release_version.return_value = None
+        mock_get_preferences_sections.return_value = [preferences]
+        self._init_command_args()
+        self.task.command_args['--set-release-version'] = '42'
+        self.task.process()
+        preferences.add_release_version.assert_called_once_with('42')
+
     @patch('kiwi.xml_state.XMLState.set_container_config_tag')
     @patch('kiwi.tasks.system_prepare.SystemPrepare')
     def test_process_system_prepare_set_container_tag(
