@@ -10,7 +10,9 @@ from pytest import (
 )
 
 from kiwi.defaults import Defaults
-from kiwi.xml_state import XMLState
+from kiwi.xml_state import (
+    XMLState, ContainerT
+)
 from kiwi.storage.disk import ptable_entry_type
 from kiwi.xml_description import XMLDescription
 
@@ -28,6 +30,19 @@ class TestXMLState:
         self._caplog = caplog
 
     def setup(self):
+        self.volume_type = namedtuple(
+            'volume_type', [
+                'name',
+                'parent',
+                'size',
+                'realpath',
+                'mountpoint',
+                'fullsize',
+                'label',
+                'attributes',
+                'is_root_volume'
+            ]
+        )
         Defaults.set_platform_name('x86_64')
         self.description = XMLDescription(
             '../data/example_config.xml'
@@ -174,12 +189,26 @@ class TestXMLState:
         assert self.state.get_system_collections() == [
             'base'
         ]
+        self.state.host_architecture = 'aarch64'
+        assert self.state.get_system_collections() == [
+            'base', 'base_for_arch'
+        ]
 
     def test_get_system_products(self):
         assert self.state.get_system_products() == [
             'openSUSE'
         ]
 
+    def test_get_system_files(self):
+        assert self.state.\
+            get_system_files()['some'].target == ''
+        assert self.state.\
+            get_system_files()['/absolute/path/to/some'].target == ''
+
+    def test_get_bootstrap_files(self):
+        assert self.state.\
+            get_bootstrap_files()['some'].target == '/some/target'
+
     def test_get_system_archives(self):
         assert self.state.get_system_archives() == [
             '/absolute/path/to/image.tgz'
@@ -383,25 +412,63 @@ class TestXMLState:
             )
         }
 
+    def test_get_containers(self):
+        assert self.state.get_containers() == [
+            ContainerT(
+                name='rmtserver_latest',
+                backend='podman',
+                container_file='/var/tmp/kiwi_containers/rmtserver_latest',
+                fetch_only=False,
+                fetch_command=[
+                    '/usr/bin/skopeo', 'copy',
+                    'docker://registry.suse.com/home/mschaefer/'
+                    'images_pubcloud/pct/rmtserver:latest',
+                    'oci-archive:/var/tmp/kiwi_containers/'
+                    'rmtserver_latest:registry.suse.com/home/mschaefer/'
+                    'images_pubcloud/pct/rmtserver:latest'
+                ],
+                load_command=[
+                    '/usr/bin/podman', 'load', '-i',
+                    '/var/tmp/kiwi_containers/rmtserver_latest'
+                ]
+            ),
+            ContainerT(
+                name='some_latest',
+                backend='docker',
+                container_file='/var/tmp/kiwi_containers/some_latest',
+                fetch_only=False,
+                fetch_command=[
+                    '/usr/bin/skopeo', 'copy',
+                    'docker://registry.suse.com/some:latest',
+                    'oci-archive:/var/tmp/kiwi_containers/'
+                    'some_latest:registry.suse.com/some:latest'
+                ],
+                load_command=[
+                    '/usr/bin/docker', 'load', '-i',
+                    '/var/tmp/kiwi_containers/some_latest'
+                ]
+            ),
+            ContainerT(
+                name='foo_latest',
+                backend='podman',
+                container_file='/var/tmp/kiwi_containers/foo_latest',
+                fetch_only=True,
+                fetch_command=[
+                    '/usr/bin/skopeo', 'copy', 'docker://docker.io/foo:latest',
+                    'oci-archive:/var/tmp/kiwi_containers/'
+                    'foo_latest:docker.io/foo:latest'
+                ],
+                load_command=[]
+            )
+        ]
+
     def test_get_volumes_custom_root_volume_name(self):
         description = XMLDescription(
             '../data/example_lvm_custom_rootvol_config.xml'
         )
         xml_data = description.load()
         state = XMLState(xml_data)
-        volume_type = namedtuple(
-            'volume_type', [
-                'name',
-                'parent',
-                'size',
-                'realpath',
-                'mountpoint',
-                'fullsize',
-                'label',
-                'attributes',
-                'is_root_volume'
-            ]
-        )
+        volume_type = self.volume_type
         assert state.get_volumes() == [
             volume_type(
                 name='myroot', parent='', size='freespace:500',
@@ -413,23 +480,82 @@ class TestXMLState:
             )
         ]
 
+    def test_get_volumes_btrfs_quota(self):
+        description = XMLDescription(
+            '../data/example_btrfs_vol_config.xml'
+        )
+        xml_data = description.load()
+        state = XMLState(xml_data)
+        volume_type = self.volume_type
+        assert state.get_volumes() == [
+            volume_type(
+                name='some', parent='', size='freespace:120',
+                realpath='some',
+                mountpoint='some', fullsize=False,
+                label=None,
+                attributes=['quota=500M'],
+                is_root_volume=False
+            ),
+            volume_type(
+                name='', parent='', size=None,
+                realpath='/',
+                mountpoint=None, fullsize=True,
+                label=None,
+                attributes=[],
+                is_root_volume=True
+            )
+        ]
+
+    def test_get_volumes_for_arch(self):
+        description = XMLDescription('../data/example_lvm_arch_config.xml')
+        xml_data = description.load()
+        state = XMLState(xml_data)
+        state.host_architecture = 'aarch64'
+        volume_type = self.volume_type
+        assert state.get_volumes() == [
+            volume_type(
+                name='usr_lib',
+                parent='',
+                size='freespace:30',
+                realpath='usr/lib',
+                mountpoint='usr/lib',
+                fullsize=False,
+                label=None,
+                attributes=[],
+                is_root_volume=False
+            ),
+            volume_type(
+                name='LVRoot',
+                parent='',
+                size=None,
+                realpath='/',
+                mountpoint=None,
+                fullsize=True,
+                label=None,
+                attributes=[],
+                is_root_volume=True
+            )
+        ]
+        state.host_architecture = 'x86_64'
+        assert state.get_volumes() == [
+            volume_type(
+                name='LVRoot',
+                parent='',
+                size=None,
+                realpath='/',
+                mountpoint=None,
+                fullsize=True,
+                label=None,
+                attributes=[],
+                is_root_volume=True
+            )
+        ]
+
     def test_get_volumes(self):
         description = XMLDescription('../data/example_lvm_default_config.xml')
         xml_data = description.load()
         state = XMLState(xml_data)
-        volume_type = namedtuple(
-            'volume_type', [
-                'name',
-                'parent',
-                'size',
-                'realpath',
-                'mountpoint',
-                'fullsize',
-                'label',
-                'attributes',
-                'is_root_volume'
-            ]
-        )
+        volume_type = self.volume_type
         assert state.get_volumes() == [
             volume_type(
                 name='usr_lib', parent='', size='size:1024',
@@ -478,19 +604,7 @@ class TestXMLState:
         description = XMLDescription('../data/example_lvm_no_root_config.xml')
         xml_data = description.load()
         state = XMLState(xml_data)
-        volume_type = namedtuple(
-            'volume_type', [
-                'name',
-                'parent',
-                'size',
-                'realpath',
-                'mountpoint',
-                'fullsize',
-                'label',
-                'attributes',
-                'is_root_volume'
-            ]
-        )
+        volume_type = self.volume_type
         assert state.get_volumes() == [
             volume_type(
                 name='LVRoot', parent='', size=None, realpath='/',
@@ -515,19 +629,7 @@ class TestXMLState:
         )
         xml_data = description.load()
         state = XMLState(xml_data)
-        volume_type = namedtuple(
-            'volume_type', [
-                'name',
-                'parent',
-                'size',
-                'realpath',
-                'mountpoint',
-                'fullsize',
-                'label',
-                'attributes',
-                'is_root_volume'
-            ]
-        )
+        volume_type = self.volume_type
         assert state.get_volumes() == [
             volume_type(
                 name='usr', parent='', size=None, realpath='usr',
